@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include "../weechat.h"
+#include "../wee-arraylist.h"
 #include "../wee-config.h"
 #include "../wee-hook.h"
 #include "../wee-infolist.h"
@@ -35,6 +36,7 @@
 #include "../wee-string.h"
 #include "../wee-utf8.h"
 #include "../../gui/gui-chat.h"
+#include "../../gui/gui-filter.h"
 #include "../../plugins/plugin.h"
 
 
@@ -61,12 +63,15 @@ hook_command_search (struct t_weechat_plugin *plugin, const char *command)
 {
     struct t_hook *ptr_hook;
 
+    if (!command)
+        return NULL;
+
     for (ptr_hook = weechat_hooks[HOOK_TYPE_COMMAND]; ptr_hook;
          ptr_hook = ptr_hook->next_hook)
     {
         if (!ptr_hook->deleted
             && (ptr_hook->plugin == plugin)
-            && (string_strcasecmp (HOOK_COMMAND(ptr_hook, command), command) == 0))
+            && (strcmp (HOOK_COMMAND(ptr_hook, command), command) == 0))
             return ptr_hook;
     }
 
@@ -308,7 +313,8 @@ hook_command (struct t_weechat_plugin *plugin, const char *command,
         return NULL;
     }
 
-    hook_get_priority_and_name (command, &priority, &ptr_command);
+    string_get_priority_and_name (command, &priority, &ptr_command,
+                                  HOOK_PRIORITY_DEFAULT);
     hook_init_data (new_hook, plugin, HOOK_TYPE_COMMAND, priority,
                     callback_pointer, callback_data);
 
@@ -358,6 +364,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
     struct t_hook *ptr_hook, *next_hook;
     struct t_hook *hook_plugin, *hook_other_plugin, *hook_other_plugin2;
     struct t_hook *hook_incomplete_command;
+    struct t_hook_exec_cb hook_exec_cb;
     char **argv, **argv_eol;
     const char *ptr_command_name;
     int argc, rc, length_command_name, allow_incomplete_commands;
@@ -405,8 +412,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
 
         if (!ptr_hook->deleted)
         {
-            if (string_strcasecmp (ptr_command_name,
-                                   HOOK_COMMAND(ptr_hook, command)) == 0)
+            if (strcmp (ptr_command_name, HOOK_COMMAND(ptr_hook, command)) == 0)
             {
                 if (ptr_hook->plugin == plugin)
                 {
@@ -426,9 +432,9 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
                 }
             }
             else if (allow_incomplete_commands
-                     && (string_strncasecmp (ptr_command_name,
-                                             HOOK_COMMAND(ptr_hook, command),
-                                             length_command_name) == 0))
+                     && (string_strncmp (ptr_command_name,
+                                         HOOK_COMMAND(ptr_hook, command),
+                                         length_command_name) == 0))
             {
                 hook_incomplete_command = ptr_hook;
                 count_incomplete_commands++;
@@ -495,7 +501,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
         else
         {
             /* execute the command! */
-            ptr_hook->running++;
+            hook_callback_start (ptr_hook, &hook_exec_cb);
             rc = (int) (HOOK_COMMAND(ptr_hook, callback))
                 (ptr_hook->callback_pointer,
                  ptr_hook->callback_data,
@@ -503,7 +509,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
                  argc,
                  argv,
                  argv_eol);
-            ptr_hook->running--;
+            hook_callback_end (ptr_hook, &hook_exec_cb);
             if (rc == WEECHAT_RC_ERROR)
                 rc = HOOK_COMMAND_EXEC_ERROR;
             else
@@ -519,6 +525,209 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
     return rc;
 }
 
+/*
+ * Gets relevance for cmd2 (existing command) compared to cmd1 (non-existing
+ * command).
+ *
+ * Both commands are in lower case.
+ *
+ * Returns a number based on the Levenshtein distance between two commands,
+ * lower is better.
+ */
+
+int
+hook_command_similar_get_relevance (const char *cmd1, int length_cmd1,
+                                    const char *cmd2, int length_cmd2)
+{
+    const char *pos;
+    int relevance;
+
+    /* perfect match if commands are the same (different case) */
+    if (strcmp (cmd1, cmd2) == 0)
+        return HOOK_COMMAND_SIMILAR_DIFF_CASE_ONLY;
+
+    /* init relevance with Levenshtein distance (lower is better) */
+    relevance = string_levenshtein (cmd1, cmd2, 1);
+
+    /* bonus if one command includes the other */
+    pos = (length_cmd1 < length_cmd2) ?
+        strstr (cmd2, cmd1) : strstr (cmd1, cmd2);
+    if (pos)
+    {
+        relevance /= 4;
+        /* extra bonus if match is at beginning */
+        if ((pos == cmd1) || (pos == cmd2))
+            relevance -= 2;
+    }
+    else
+    {
+        /* malus if no chars in common between two words */
+        if (string_get_common_bytes_count (cmd1, cmd2) == 0)
+            relevance *= 2;
+    }
+
+    return relevance;
+}
+
+/*
+ * Compares similar commands to sort them by relevance (lower number first:
+ * best relevance).
+ */
+
+int
+hook_command_similar_cmp_cb (void *data, struct t_arraylist *arraylist,
+                             void *pointer1, void *pointer2)
+{
+    struct t_hook_command_similar *ptr_cmd1, *ptr_cmd2;
+
+    /* make C compiler happy */
+    (void) data;
+    (void) arraylist;
+
+    ptr_cmd1 = (struct t_hook_command_similar *)pointer1;
+    ptr_cmd2 = (struct t_hook_command_similar *)pointer2;
+
+    if (ptr_cmd1->relevance < ptr_cmd2->relevance)
+        return -1;
+
+    if (ptr_cmd1->relevance > ptr_cmd2->relevance)
+        return 1;
+
+    return string_strcasecmp (ptr_cmd1->command, ptr_cmd2->command);
+}
+
+/*
+ * Frees a similar command.
+ */
+
+void
+hook_command_similar_free_cb (void *data, struct t_arraylist *arraylist,
+                              void *pointer)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) arraylist;
+
+    free (pointer);
+}
+
+/*
+ * Builds an arraylist with similar commands.
+ *
+ * Note: result must be freed after use.
+ */
+
+struct t_arraylist *
+hook_command_build_list_similar_commands (const char *command)
+{
+    struct t_arraylist *list_commands;
+    struct t_hook *ptr_hook;
+    struct t_hook_command_similar *cmd_similar;
+    char *cmd1, *cmd2;
+    int length_cmd1, length_cmd2, relevance;
+
+    cmd1 = string_tolower (command);
+    if (!cmd1)
+        return NULL;
+
+    length_cmd1 = strlen (cmd1);
+
+    list_commands = arraylist_new (64, 1, 0,
+                                   &hook_command_similar_cmp_cb, NULL,
+                                   &hook_command_similar_free_cb, NULL);
+
+    for (ptr_hook = weechat_hooks[HOOK_TYPE_COMMAND]; ptr_hook;
+         ptr_hook = ptr_hook->next_hook)
+    {
+        if (ptr_hook->deleted)
+            continue;
+        cmd2 = string_tolower (HOOK_COMMAND(ptr_hook, command));
+        if (!cmd2)
+            continue;
+        length_cmd2 = strlen (cmd2);
+        relevance = hook_command_similar_get_relevance (cmd1, length_cmd1,
+                                                        cmd2, length_cmd2);
+        cmd_similar = (struct t_hook_command_similar *)malloc (
+            sizeof (*cmd_similar));
+        if (cmd_similar)
+        {
+            cmd_similar->command = HOOK_COMMAND(ptr_hook, command);
+            cmd_similar->relevance = relevance;
+        }
+        arraylist_add (list_commands, cmd_similar);
+        free (cmd2);
+    }
+
+    free (cmd1);
+
+    return list_commands;
+}
+
+/*
+ * Displays an error on unknown command, with a list of existing similar
+ * command names.
+ */
+
+void
+hook_command_display_error_unknown (const char *command)
+{
+    struct t_arraylist *list_commands;
+    struct t_hook_command_similar *cmd_similar;
+    char **str_commands;
+    int i, list_size, found, found_diff_case_only;
+
+    if (!command || !command[0])
+        return;
+
+    list_commands = hook_command_build_list_similar_commands (command);
+    if (!list_commands)
+        return;
+
+    str_commands = string_dyn_alloc (256);
+    if (!str_commands)
+    {
+        arraylist_free (list_commands);
+        return;
+    }
+
+    found = 0;
+    found_diff_case_only = 0;
+    list_size = arraylist_size (list_commands);
+    for (i = 0; i < list_size; i++)
+    {
+        cmd_similar = (struct t_hook_command_similar *)arraylist_get (
+            list_commands, i);
+        if (cmd_similar->relevance >= 3)
+            break;
+        if (found > 0)
+            string_dyn_concat (str_commands, ", ", -1);
+        string_dyn_concat (str_commands, cmd_similar->command, -1);
+        found++;
+        if (cmd_similar->relevance == HOOK_COMMAND_SIMILAR_DIFF_CASE_ONLY)
+            found_diff_case_only++;
+        if (found >= 5)
+            break;
+    }
+    if (found == 0)
+        string_dyn_concat (str_commands, "-", -1);
+
+    gui_chat_printf_date_tags (
+        NULL,
+        0, GUI_FILTER_TAG_NO_FILTER,
+        (found_diff_case_only > 0) ?
+        _("%sUnknown command \"%s\" (commands are case sensitive, "
+          "type /help for help), "
+          "commands with similar name: %s") :
+        _("%sUnknown command \"%s\" (type /help for help), "
+          "commands with similar name: %s"),
+        gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
+        command,
+        *str_commands);
+
+    string_dyn_free (str_commands, 1);
+    arraylist_free (list_commands);
+}
+
 /*
  * Frees data in a command hook.
  */
