@@ -489,6 +489,76 @@ completion_list_add_buffer_properties_set_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds a buffer local variable to completions list (for `/buffer setauto`).
+ */
+
+void
+completion_list_map_buffer_local_variable_setauto_cb (void *data,
+                                                      struct t_hashtable *hashtable,
+                                                      const void *key,
+                                                      const void *value)
+{
+    char str_localvar[4096];
+
+    /* make C compiler happy */
+    (void) hashtable;
+    (void) value;
+
+    snprintf (str_localvar, sizeof (str_localvar),
+              "localvar_set_%s", (const char *)key);
+    gui_completion_list_add ((struct t_gui_completion *)data,
+                             str_localvar,
+                             0, WEECHAT_LIST_POS_SORT);
+}
+
+/*
+ * Adds buffer properties (that can be set), local variables and key bindings
+ * to completion list.
+ */
+
+int
+completion_list_add_buffer_properties_setauto_cb (const void *pointer, void *data,
+                                                  const char *completion_item,
+                                                  struct t_gui_buffer *buffer,
+                                                  struct t_gui_completion *completion)
+{
+    struct t_gui_key *ptr_key;
+    char str_key[1024];
+    int i;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    /* add buffer properties */
+    for (i = 0; gui_buffer_properties_set[i]; i++)
+    {
+        gui_completion_list_add (completion,
+                                 gui_buffer_properties_set[i],
+                                 0, WEECHAT_LIST_POS_SORT);
+    }
+
+    /* add buffer local variables */
+    hashtable_map (completion->buffer->local_variables,
+                   &completion_list_map_buffer_local_variable_setauto_cb,
+                   completion);
+
+    /* add buffer keys */
+    for (ptr_key = completion->buffer->keys; ptr_key;
+         ptr_key = ptr_key->next_key)
+    {
+        snprintf (str_key, sizeof (str_key), "key_bind_%s", ptr_key->key);
+        gui_completion_list_add (completion, str_key, 0, WEECHAT_LIST_POS_SORT);
+        snprintf (str_key, sizeof (str_key), "key_unbind_%s", ptr_key->key);
+        gui_completion_list_add (completion, str_key, 0, WEECHAT_LIST_POS_SORT);
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds buffer properties (that can be read) to completion list.
  */
@@ -1461,59 +1531,31 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                             }
                             break;
                         case CONFIG_OPTION_TYPE_INTEGER:
-                            if (option_found->string_values)
-                            {
-                                for (i = 0; option_found->string_values[i]; i++)
-                                {
-                                    gui_completion_list_add (completion,
-                                                             option_found->string_values[i],
-                                                             0, WEECHAT_LIST_POS_SORT);
-                                }
-                                gui_completion_list_add (completion, "++1",
-                                                         0, WEECHAT_LIST_POS_END);
+                            if (option_found->value && CONFIG_INTEGER(option_found) > option_found->min)
                                 gui_completion_list_add (completion, "--1",
-                                                         0, WEECHAT_LIST_POS_END);
-                                if (option_found->value)
+                                                         0, WEECHAT_LIST_POS_BEGINNING);
+                            if (option_found->value && CONFIG_INTEGER(option_found) < option_found->max)
+                                gui_completion_list_add (completion, "++1",
+                                                         0, WEECHAT_LIST_POS_BEGINNING);
+                            if (option_found->value)
+                            {
+                                length = 64;
+                                value_string = malloc (length);
+                                if (value_string)
                                 {
+                                    snprintf (value_string, length,
+                                              "%d", CONFIG_INTEGER(option_found));
                                     gui_completion_list_add (completion,
-                                                             option_found->string_values[CONFIG_INTEGER(option_found)],
-                                                             0, WEECHAT_LIST_POS_BEGINNING);
-                                }
-                                else
-                                {
-                                    gui_completion_list_add (completion,
-                                                             WEECHAT_CONFIG_OPTION_NULL,
+                                                             value_string,
                                                              0, WEECHAT_LIST_POS_BEGINNING);
+                                    free (value_string);
                                 }
                             }
                             else
                             {
-                                if (option_found->value && CONFIG_INTEGER(option_found) > option_found->min)
-                                    gui_completion_list_add (completion, "--1",
-                                                             0, WEECHAT_LIST_POS_BEGINNING);
-                                if (option_found->value && CONFIG_INTEGER(option_found) < option_found->max)
-                                    gui_completion_list_add (completion, "++1",
-                                                             0, WEECHAT_LIST_POS_BEGINNING);
-                                if (option_found->value)
-                                {
-                                    length = 64;
-                                    value_string = malloc (length);
-                                    if (value_string)
-                                    {
-                                        snprintf (value_string, length,
-                                                  "%d", CONFIG_INTEGER(option_found));
-                                        gui_completion_list_add (completion,
-                                                                 value_string,
-                                                                 0, WEECHAT_LIST_POS_BEGINNING);
-                                        free (value_string);
-                                    }
-                                }
-                                else
-                                {
-                                    gui_completion_list_add (completion,
-                                                             WEECHAT_CONFIG_OPTION_NULL,
-                                                             0, WEECHAT_LIST_POS_BEGINNING);
-                                }
+                                gui_completion_list_add (completion,
+                                                         WEECHAT_CONFIG_OPTION_NULL,
+                                                         0, WEECHAT_LIST_POS_BEGINNING);
                             }
                             break;
                         case CONFIG_OPTION_TYPE_STRING:
@@ -1567,6 +1609,30 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                                                          0, WEECHAT_LIST_POS_BEGINNING);
                             }
                             break;
+                        case CONFIG_OPTION_TYPE_ENUM:
+                            for (i = 0; option_found->string_values[i]; i++)
+                            {
+                                gui_completion_list_add (completion,
+                                                         option_found->string_values[i],
+                                                         0, WEECHAT_LIST_POS_SORT);
+                            }
+                            gui_completion_list_add (completion, "++1",
+                                                     0, WEECHAT_LIST_POS_END);
+                            gui_completion_list_add (completion, "--1",
+                                                     0, WEECHAT_LIST_POS_END);
+                            if (option_found->value)
+                            {
+                                gui_completion_list_add (completion,
+                                                         option_found->string_values[CONFIG_ENUM(option_found)],
+                                                         0, WEECHAT_LIST_POS_BEGINNING);
+                            }
+                            else
+                            {
+                                gui_completion_list_add (completion,
+                                                         WEECHAT_CONFIG_OPTION_NULL,
+                                                         0, WEECHAT_LIST_POS_BEGINNING);
+                            }
+                            break;
                         case CONFIG_NUM_OPTION_TYPES:
                             break;
                     }
@@ -2005,6 +2071,119 @@ completion_list_add_env_value_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds a buffer local variable for /eval to completions list.
+ */
+
+void
+completion_list_map_eval_buffer_local_variable_cb (void *data,
+                                                   struct t_hashtable *hashtable,
+                                                   const void *key, const void *value)
+{
+    char *name;
+    int length;
+
+    /* make C compiler happy */
+    (void) hashtable;
+    (void) value;
+
+    length = strlen (key) + 3 + 1;
+    name = malloc (length);
+    if (name)
+    {
+        snprintf (name, length, "${%s}", (const char *)key);
+        gui_completion_list_add ((struct t_gui_completion *)data,
+                                 name, 0, WEECHAT_LIST_POS_SORT);
+        free (name);
+    }
+}
+
+/*
+ * Adds /eval variables to completion list.
+ */
+
+int
+completion_list_add_eval_variables_cb (const void *pointer, void *data,
+                                       const char *completion_item,
+                                       struct t_gui_buffer *buffer,
+                                       struct t_gui_completion *completion)
+{
+    char *eval_variables[] = {
+        "${\\xxx}",
+        "${base_decode:base,xxx}",
+        "${base_encode:base,xxx}",
+        "${calc:xxx}",
+        "${chars:range}",
+        "${color:xxx}",
+        "${cut:+max,suffix,string}",
+        "${cut:max,suffix,string}",
+        "${cutscr:+max,suffix,string}",
+        "${cutscr:max,suffix,string}",
+        "${date:format}",
+        "${date}",
+        "${define:name,value}",
+        "${env:XXX}",
+        "${esc:xxx}",
+        "${eval:xxx}",
+        "${eval_cond:xxx}",
+        "${file.section.option}",
+        "${hdata.var1.var2}",
+        "${hdata[list].var1.var2}",
+        "${hdata[ptr].var1.var2}",
+        "${hdata[ptr_name].var1.var2}",
+        "${hide:char,string}",
+        "${if:condition?value_if_true:value_if_false}",
+        "${info:name,arguments}",
+        "${length:xxx}",
+        "${lengthscr:xxx}",
+        "${lower:xxx}",
+        "${modifier:name,data,xxx}",
+        "${random:min,max}",
+        "${raw:xxx}",
+        "${re:+}",
+        "${re:N}",
+        "${repeat:count,string}",
+        "${rev:xxx}",
+        "${revscr:xxx}",
+        "${sec.data.xxx}",
+        "${split:count,separators,flags,xxx}",
+        "${split:number,separators,flags,xxx}",
+        "${split:random,separators,flags,xxx}",
+        "${split_shell:count,xxx}",
+        "${split_shell:number,xxx}",
+        "${split_shell:random,xxx}",
+        "${translate:xxx}",
+        "${upper:xxx}",
+        "${weechat_cache_dir}",
+        "${weechat_config_dir}",
+        "${weechat_data_dir}",
+        "${weechat_runtime_dir}",
+        "${window}",
+        "${window.buffer}",
+        "${window.buffer.xxx}",
+        NULL,
+    };
+    int i;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    for (i = 0; eval_variables[i]; i++)
+    {
+        gui_completion_list_add (completion, eval_variables[i],
+                                 0, WEECHAT_LIST_POS_SORT);
+    }
+
+    hashtable_map (completion->buffer->local_variables,
+                   &completion_list_map_eval_buffer_local_variable_cb,
+                   completion);
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds hooks for completions done by WeeChat core.
  */
@@ -2030,6 +2209,9 @@ completion_init ()
     hook_completion (NULL, "buffer_properties_set",
                      N_("properties that can be set on a buffer"),
                      &completion_list_add_buffer_properties_set_cb, NULL, NULL);
+    hook_completion (NULL, "buffer_properties_setauto",
+                     N_("properties that can be automatically set on a buffer"),
+                     &completion_list_add_buffer_properties_setauto_cb, NULL, NULL);
     hook_completion (NULL, "buffer_properties_get",
                      N_("properties that can be read on a buffer"),
                      &completion_list_add_buffer_properties_get_cb, NULL, NULL);
@@ -2146,4 +2328,7 @@ completion_init ()
     hook_completion (NULL, "env_value",
                      N_("value of an environment variable"),
                      &completion_list_add_env_value_cb, NULL, NULL);
+    hook_completion (NULL, "eval_variables",
+                     N_("variables that can be used in /eval command"),
+                     &completion_list_add_eval_variables_cb, NULL, NULL);
 }
