@@ -142,6 +142,7 @@ extern struct t_config_section *weechat_config_section_signal;
 extern struct t_config_section *weechat_config_section_bar;
 extern struct t_config_section *weechat_config_section_custom_bar_item;
 extern struct t_config_section *weechat_config_section_layout;
+extern struct t_config_section *weechat_config_section_buffer;
 extern struct t_config_section *weechat_config_section_notify;
 extern struct t_config_section *weechat_config_section_filter;
 extern struct t_config_section *weechat_config_section_key[];
@@ -400,6 +401,8 @@ extern struct t_config_option *config_weechat_debug_get (const char *plugin_name
 extern int config_weechat_debug_set (const char *plugin_name,
                                      const char *value);
 extern void config_weechat_debug_set_all ();
+extern int config_weechat_buffer_set (struct t_gui_buffer *buffer,
+                                      const char *property, const char *value);
 extern int config_weechat_notify_set (struct t_gui_buffer *buffer,
                                       const char *notify);
 extern void config_get_item_time (char *text_time, int max_length);
