@@ -126,7 +126,7 @@ doc_gen_open_file (const char *path, const char *doc, const char *name,
     if (!file)
     {
         string_fprintf (stderr,
-                        "doc generator: ERROR: unable to write file \"%s\"",
+                        "doc generator: ERROR: unable to write file \"%s\"\n",
                         filename);
         return NULL;
     }
@@ -144,7 +144,7 @@ doc_gen_open_file (const char *path, const char *doc, const char *name,
 
 /*
  * Closes the file and renames it without ".temp" suffix, if the target name
- * does not exist of if it exists with a different (obsolete) content.
+ * does not exist or if it exists with a different (obsolete) content.
  *
  * If the target name exists with same content it's kept as-is (so the
  * timestamp does not change) and the temporary file is just deleted.
@@ -317,7 +317,7 @@ doc_gen_user_commands (const char *path, const char *lang)
             HOOK_COMMAND(ptr_hook, command),
             TRANS(HOOK_COMMAND(ptr_hook, description)));
 
-        length = 1 + utf8_strlen (HOOK_COMMAND(ptr_hook, command)) + 2;
+        length = 1 + utf8_strlen_screen (HOOK_COMMAND(ptr_hook, command)) + 2;
         snprintf (format, sizeof (format), "%%-%ds%%s\n", length);
         ptr_args = TRANS(HOOK_COMMAND(ptr_hook, args));
         first_line = 1;
@@ -541,19 +541,11 @@ doc_gen_user_options (const char *path, const char *lang)
                 values = strdup ("on, off");
                 break;
             case CONFIG_OPTION_TYPE_INTEGER:
-                if (ptr_option->string_values)
-                {
-                    values = string_rebuild_split_string (
-                        (const char **)ptr_option->string_values, ", ", 0, -1);
-                }
-                else
-                {
-                    snprintf (str_values, sizeof (str_values),
-                              "%d .. %d",
-                              ptr_option->min,
-                              ptr_option->max);
-                    values = strdup (str_values);
-                }
+                snprintf (str_values, sizeof (str_values),
+                          "%d .. %d",
+                          ptr_option->min,
+                          ptr_option->max);
+                values = strdup (str_values);
                 break;
             case CONFIG_OPTION_TYPE_STRING:
                 if (ptr_option->max <= 0)
@@ -573,6 +565,10 @@ doc_gen_user_options (const char *path, const char *lang)
             case CONFIG_OPTION_TYPE_COLOR:
                 values = strdup (command_help_option_color_values ());
                 break;
+            case CONFIG_OPTION_TYPE_ENUM:
+                values = string_rebuild_split_string (
+                    (const char **)ptr_option->string_values, ", ", 0, -1);
+                break;
             default:
                 values = NULL;
                 break;
@@ -1652,7 +1648,7 @@ doc_generate (const char *path)
     {
         string_fprintf (
             stderr,
-            "doc generator: ERROR: failed to create directory \"%s\")",
+            "doc generator: ERROR: failed to create directory \"%s\")\n",
             path);
         goto end;
     }
@@ -1662,14 +1658,26 @@ doc_generate (const char *path)
      * (this is used to generate documentation without installing WeeChat,
      * that means no need to run `make install`)
      */
+#ifdef ENABLE_NLS
     localedir = getenv ("WEECHAT_DOCGEN_LOCALEDIR");
     if (localedir && localedir[0])
         bindtextdomain (PACKAGE, localedir);
+#endif /* ENABLE_NLS */
 
     for (i = 0; locales[i]; i++)
     {
         setenv ("LANGUAGE", locales[i], 1);
-        setlocale (LC_ALL, locales[i]);
+        if (!setlocale (LC_ALL, locales[i]))
+        {
+            /* warning on missing locale */
+            string_fprintf (
+                stderr,
+                "doc generator: WARNING: failed to set locale \"%s\", "
+                "docs will include auto-generated English content\n",
+                locales[i]);
+            /* fallback to English */
+            setlocale (LC_ALL, "C");
+        }
         memcpy (lang, locales[i], 2);
         lang[2] = '\0';
         for (j = 0; doc_gen_functions[j]; j++)
