@@ -1167,7 +1167,7 @@ char *
 eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
                       struct t_eval_context *eval_context)
 {
-    char *value, *old_value, *var_name, str_value[128], *pos, *property;
+    char *value, *var_name, str_value[128], *pos, *property;
     const char *ptr_value, *hdata_name, *ptr_var_name, *pos_open_paren;
     int type, debug_id;
     struct t_hashtable *hashtable;
@@ -1272,7 +1272,8 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
                     property = string_strndup (pos + 1,
                                                pos_open_paren - pos - 1);
                     ptr_value = hashtable_get_string (hashtable, property);
-                    free (property);
+                    if (property)
+                        free (property);
                     value = (ptr_value) ? strdup (ptr_value) : NULL;
                     break;
                 }
@@ -1326,13 +1327,12 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
             goto end;
 
         hdata = hook_hdata_get (NULL, hdata_name);
-        old_value = value;
+        if (value)
+            free (value);
         value = eval_hdata_get_value (hdata,
                                       pointer,
-                                      (pos) ? pos + 1 : NULL,
+                                      pos + 1,
                                       eval_context);
-        if (old_value)
-            free (old_value);
     }
 
 end:
@@ -1463,7 +1463,7 @@ end:
  *  - a string to evaluate (format: eval:xxx)
  *  - a condition to evaluate (format: eval_cond:xxx)
  *  - a string with escaped chars (format: esc:xxx or \xxx)
- *  - a string with a range of chars (format: chars:xxx)
+ *  - a string with a range of chars (format: chars:range)
  *  - a string converted to lower case (format: lower:xxx)
  *  - a string converted to upper case (format: upper:xxx)
  *  - a string with chars to hide (format: hide:char,string)
@@ -1478,15 +1478,15 @@ end:
  *  - split string (format: split:number,separators,flags,xxx
  *    or split:count,separators,flags,xxx
  *    or split:random,separators,flags,xxx)
- *  - split shell arguments (format: split:number,xxx or split:count,xxx
- *    or split:random,xxx)
+ *  - split shell arguments (format: split_shell:number,xxx or
+ *    split_shell:count,xxx or split_shell:random,xxx)
  *  - a regex group captured (format: re:N (0.99) or re:+)
  *  - a color (format: color:xxx)
  *  - a modifier (format: modifier:name,data,xxx)
  *  - an info (format: info:name,arguments)
  *  - a base 16/32/64 encoded/decoded string (format: base_encode:base,xxx
  *    or base_decode:base,xxx)
- *  - current date/time (format: date or date:xxx)
+ *  - current date/time (format: date or date:format)
  *  - an environment variable (format: env:XXX)
  *  - a ternary operator (format: if:condition?value_if_true:value_if_false)
  *  - calculate result of an expression (format: calc:xxx)
@@ -1832,11 +1832,6 @@ eval_replace_vars_cb (void *data, const char *text)
                                 EVAL_STR_TRUE : EVAL_STR_FALSE);
                 goto end;
             case CONFIG_OPTION_TYPE_INTEGER:
-                if (ptr_option->string_values)
-                {
-                    value = strdup (ptr_option->string_values[CONFIG_INTEGER(ptr_option)]);
-                    goto end;
-                }
                 snprintf (str_value, sizeof (str_value),
                           "%d", CONFIG_INTEGER(ptr_option));
                 value = strdup (str_value);
@@ -1847,6 +1842,9 @@ eval_replace_vars_cb (void *data, const char *text)
             case CONFIG_OPTION_TYPE_COLOR:
                 value = strdup (gui_color_get_name (CONFIG_COLOR(ptr_option)));
                 goto end;
+            case CONFIG_OPTION_TYPE_ENUM:
+                value = strdup (ptr_option->string_values[CONFIG_ENUM(ptr_option)]);
+                goto end;
             case CONFIG_NUM_OPTION_TYPES:
                 value = strdup ("");
                 goto end;
