@@ -314,6 +314,9 @@ infolist_new_var_time (struct t_infolist_item *item,
 struct t_infolist_item *
 infolist_next (struct t_infolist *infolist)
 {
+    if (!infolist)
+        return NULL;
+
     if (!infolist->ptr_item)
     {
         infolist->ptr_item = infolist->items;
@@ -332,6 +335,9 @@ infolist_next (struct t_infolist *infolist)
 struct t_infolist_item *
 infolist_prev (struct t_infolist *infolist)
 {
+    if (!infolist)
+        return NULL;
+
     if (!infolist->ptr_item)
     {
         infolist->ptr_item = infolist->last_item;
@@ -348,6 +354,9 @@ infolist_prev (struct t_infolist *infolist)
 void
 infolist_reset_item_cursor (struct t_infolist *infolist)
 {
+    if (!infolist)
+        return;
+
     infolist->ptr_item = NULL;
 }
 
@@ -366,7 +375,7 @@ infolist_search_var (struct t_infolist *infolist, const char *name)
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, name) == 0)
+        if (strcmp (ptr_var->name, name) == 0)
             return ptr_var;
     }
 
@@ -447,7 +456,7 @@ infolist_integer (struct t_infolist *infolist, const char *var)
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, var) == 0)
+        if (strcmp (ptr_var->name, var) == 0)
         {
             if (ptr_var->type == INFOLIST_INTEGER)
                 return *((int *)ptr_var->value);
@@ -475,7 +484,7 @@ infolist_string (struct t_infolist *infolist, const char *var)
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, var) == 0)
+        if (strcmp (ptr_var->name, var) == 0)
         {
             if (ptr_var->type == INFOLIST_STRING)
                 return (char *)ptr_var->value;
@@ -503,7 +512,7 @@ infolist_pointer (struct t_infolist *infolist, const char *var)
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, var) == 0)
+        if (strcmp (ptr_var->name, var) == 0)
         {
             if (ptr_var->type == INFOLIST_POINTER)
                 return ptr_var->value;
@@ -534,7 +543,7 @@ infolist_buffer (struct t_infolist *infolist, const char *var,
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, var) == 0)
+        if (strcmp (ptr_var->name, var) == 0)
         {
             if (ptr_var->type == INFOLIST_BUFFER)
             {
@@ -565,7 +574,7 @@ infolist_time (struct t_infolist *infolist, const char *var)
     for (ptr_var = infolist->ptr_item->vars; ptr_var;
          ptr_var = ptr_var->next_var)
     {
-        if (string_strcasecmp (ptr_var->name, var) == 0)
+        if (strcmp (ptr_var->name, var) == 0)
         {
             if (ptr_var->type == INFOLIST_TIME)
                 return *((time_t *)ptr_var->value);
