@@ -337,11 +337,11 @@ network_is_ip_address (const char *address)
         return 0;
 
     /* valid IPv4? */
-    if (inet_pton (AF_INET, address, &server_addr.sin_addr))
+    if (inet_pton (AF_INET, address, &server_addr.sin_addr) == 1)
         return 1;
 
     /* valid IPv6? */
-    if (inet_pton (AF_INET6, address, &server_addr6.sin6_addr))
+    if (inet_pton (AF_INET6, address, &server_addr6.sin6_addr) == 1)
         return 1;
 
     /* not a valid IP address */
@@ -554,11 +554,13 @@ network_pass_socks4proxy (struct t_proxy *proxy, int sock, const char *address,
     socks4.method = 1;
     socks4.port = htons (port);
     network_resolve (address, ip_addr, NULL);
-    socks4.address = inet_addr (ip_addr);
     strncpy (socks4.user, username, sizeof (socks4.user) - 1);
 
     free (username);
 
+    if (inet_pton (AF_INET, ip_addr, &socks4.address) != 1)
+        return 0;
+
     length = 8 + strlen (socks4.user) + 1;
     if (network_send_with_retry (sock, (char *) &socks4, length, 0) != length)
         return 0;
@@ -767,7 +769,7 @@ network_pass_proxy (const char *proxy, int sock, const char *address, int port)
     ptr_proxy = proxy_search (proxy);
     if (ptr_proxy)
     {
-        switch (CONFIG_INTEGER(ptr_proxy->options[PROXY_OPTION_TYPE]))
+        switch (CONFIG_ENUM(ptr_proxy->options[PROXY_OPTION_TYPE]))
         {
             case PROXY_TYPE_HTTP:
                 rc = network_pass_httpproxy (ptr_proxy, sock, address, port);
