@@ -58,6 +58,9 @@
 #include "../gui-nicklist.h"
 #include "../gui-window.h"
 #include "gui-curses.h"
+#include "gui-curses-color.h"
+#include "gui-curses-key.h"
+#include "gui-curses-window.h"
 
 
 volatile sig_atomic_t gui_signal_sigwinch_received = 0;  /* sigwinch signal */
@@ -111,7 +114,7 @@ gui_main_get_password (const char **prompt, char *password, int size)
         /* enter */
         if (ch == '\n')
             break;
-        /* terminal lost or ctrl-C */
+        /* terminal lost or ctrl-c */
         if ((ch == ERR) || (ch == 3))
         {
             password[0] = 3;
@@ -160,11 +163,9 @@ void
 gui_main_init ()
 {
     struct t_gui_buffer *ptr_buffer;
-    struct t_gui_bar *ptr_bar;
-    struct t_gui_bar_window *ptr_bar_win;
     char title[256];
 
-    /* allow Ctrl-C to quit WeeChat in headless mode */
+    /* allow ctrl-c to quit WeeChat in headless mode */
     if (weechat_headless)
         signal_catch (SIGINT, &gui_main_signal_sigint);
 
@@ -235,24 +236,8 @@ gui_main_init ()
             }
         }
 
-        /*
-         * create bar windows for root bars (they were read from config,
-         * but no window was created, GUI was not initialized)
-         */
-        for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
-        {
-            if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
-                && (!ptr_bar->bar_window))
-            {
-                gui_bar_window_new (ptr_bar, NULL);
-            }
-        }
-        for (ptr_bar_win = gui_windows->bar_windows;
-             ptr_bar_win; ptr_bar_win = ptr_bar_win->next_bar_window)
-        {
-            gui_bar_window_calculate_pos_size (ptr_bar_win, gui_windows);
-            gui_bar_window_create_win (ptr_bar_win);
-        }
+        /* switch to buffer */
+        gui_window_switch_to_buffer (gui_current_window, ptr_buffer, 0);
     }
 
     if (CONFIG_BOOLEAN(config_look_mouse))
