@@ -30,6 +30,7 @@
 #include "../core/weechat.h"
 #include "../core/wee-arraylist.h"
 #include "../core/wee-config.h"
+#include "../core/wee-debug.h"
 #include "../core/wee-hashtable.h"
 #include "../core/wee-hdata.h"
 #include "../core/wee-hook.h"
@@ -37,6 +38,7 @@
 #include "../core/wee-log.h"
 #include "../core/wee-string.h"
 #include "../core/wee-utf8.h"
+#include "../core/wee-util.h"
 #include "../plugins/plugin.h"
 #include "gui-bar-item.h"
 #include "gui-bar.h"
@@ -97,6 +99,30 @@ gui_bar_item_valid (struct t_gui_bar_item *bar_item)
     return 0;
 }
 
+/*
+ * Searches for a default bar item by name.
+ *
+ * Returns index in gui_bar_item_names[], -1 if not found.
+ */
+
+int
+gui_bar_item_search_default (const char *item_name)
+{
+    int i;
+
+    if (!item_name || !item_name[0])
+        return -1;
+
+    for (i = 0; i < GUI_BAR_NUM_ITEMS; i++)
+    {
+        if (strcmp (gui_bar_item_names[i], item_name) == 0)
+            return i;
+    }
+
+    /* default bar item not found */
+    return -1;
+}
+
 /*
  * Searches for a bar item by name.
  */
@@ -359,9 +385,11 @@ gui_bar_item_get_value (struct t_gui_bar *bar, struct t_gui_window *window,
                         int item, int subitem)
 {
     char *item_value, delimiter_color[32], bar_color[32];
-    char **result, str_attr[8];
+    char **result, str_attr[8], *str_diff;
     struct t_gui_buffer *buffer;
     struct t_gui_bar_item *ptr_item;
+    struct timeval start_time, end_time;
+    long long time_diff;
 
     if (!bar || !bar->items_array[item][subitem])
         return NULL;
@@ -383,6 +411,15 @@ gui_bar_item_get_value (struct t_gui_bar *bar, struct t_gui_window *window,
                                                     bar->items_name[item][subitem]);
         if (ptr_item && ptr_item->build_callback)
         {
+            if (debug_long_callbacks > 0)
+            {
+                gettimeofday (&start_time, NULL);
+            }
+            else
+            {
+                start_time.tv_sec = 0;
+                start_time.tv_usec = 0;
+            }
             item_value = (ptr_item->build_callback) (
                 ptr_item->build_callback_pointer,
                 ptr_item->build_callback_data,
@@ -390,6 +427,24 @@ gui_bar_item_get_value (struct t_gui_bar *bar, struct t_gui_window *window,
                 window,
                 buffer,
                 NULL);
+            if ((debug_long_callbacks > 0) && (start_time.tv_sec > 0))
+            {
+                gettimeofday (&end_time, NULL);
+                time_diff = util_timeval_diff (&start_time, &end_time);
+                if (time_diff >= debug_long_callbacks)
+                {
+                    str_diff = util_get_microseconds_string (time_diff);
+                    log_printf (
+                        _("debug: long callback: bar: %s, item: %s, plugin: %s, "
+                          "time elapsed: %s"),
+                        bar->name,
+                        ptr_item->name,
+                        plugin_get_name (ptr_item->plugin),
+                        str_diff);
+                    if (str_diff)
+                        free (str_diff);
+                }
+            }
         }
         if (item_value && !item_value[0])
         {
@@ -587,7 +642,7 @@ gui_bar_item_update (const char *item_name)
                     if (!CONFIG_BOOLEAN(ptr_bar->options[GUI_BAR_OPTION_HIDDEN]))
                         check_bar_conditions = 1;
 
-                    if (CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
+                    if (CONFIG_ENUM(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
                     {
                         if (ptr_bar->bar_window)
                         {
@@ -621,7 +676,7 @@ gui_bar_item_update (const char *item_name)
          */
         if (check_bar_conditions)
         {
-            if (CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
+            if (CONFIG_ENUM(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
             {
                 condition_ok = gui_bar_check_conditions (ptr_bar, NULL);
                 if ((condition_ok && !ptr_bar->bar_window)
