@@ -74,7 +74,7 @@ gui_completion_word_compare_cb (void *data,
     completion_word1 = (struct t_gui_completion_word *)pointer1;
     completion_word2 = (struct t_gui_completion_word *)pointer2;
 
-    return string_strcasecmp (completion_word1->word, completion_word2->word);
+    return string_strcmp (completion_word1->word, completion_word2->word);
 }
 
 /*
@@ -319,6 +319,9 @@ gui_completion_search_command (struct t_weechat_plugin *plugin,
     struct t_hook *ptr_hook, *hook_for_other_plugin, *hook_incomplete_command;
     int length_command, allow_incomplete_commands, count_incomplete_commands;
 
+    if (!command)
+        return NULL;
+
     hook_for_other_plugin = NULL;
     hook_incomplete_command = NULL;
     length_command = utf8_strlen (command);
@@ -332,17 +335,16 @@ gui_completion_search_command (struct t_weechat_plugin *plugin,
             && HOOK_COMMAND(ptr_hook, command)
             && HOOK_COMMAND(ptr_hook, command)[0])
         {
-            if (string_strcasecmp (HOOK_COMMAND(ptr_hook, command),
-                                   command) == 0)
+            if (strcmp (HOOK_COMMAND(ptr_hook, command), command) == 0)
             {
                 if (ptr_hook->plugin == plugin)
                     return ptr_hook;
                 hook_for_other_plugin = ptr_hook;
             }
             else if (allow_incomplete_commands
-                     && (string_strncasecmp (HOOK_COMMAND(ptr_hook, command),
-                                             command,
-                                             length_command) == 0))
+                     && (string_strncmp (HOOK_COMMAND(ptr_hook, command),
+                                         command,
+                                         length_command) == 0))
             {
                 hook_incomplete_command = ptr_hook;
                 count_incomplete_commands++;
@@ -478,8 +480,8 @@ gui_completion_list_add (struct t_gui_completion *completion, const char *word,
     if (!completion->base_word || !completion->base_word[0]
         || (nick_completion && (gui_completion_nickncmp (completion->base_word, word,
                                                          utf8_strlen (completion->base_word)) == 0))
-        || (!nick_completion && (string_strncasecmp (completion->base_word, word,
-                                                     utf8_strlen (completion->base_word)) == 0)))
+        || (!nick_completion && (string_strncmp (completion->base_word, word,
+                                                 utf8_strlen (completion->base_word)) == 0)))
     {
         completion_word = malloc (sizeof (*completion_word));
         if (completion_word)
@@ -810,7 +812,7 @@ gui_completion_find_context (struct t_gui_completion *completion,
                              const char *data, int pos)
 {
     int i, size, command_arg, pos_start, pos_end;
-    const char *ptr_command, *ptr_data, *prev_char;
+    const char *ptr_command, *ptr_data, *ptr_space, *ptr_newline, *prev_char;
 
     /* look for context */
     gui_completion_free_data (completion);
@@ -843,12 +845,15 @@ gui_completion_find_context (struct t_gui_completion *completion,
         ptr_data = data;
         while (ptr_data && (ptr_data < data + pos))
         {
-            ptr_data = strchr (ptr_data, ' ');
+            ptr_space = strchr (ptr_data, ' ');
+            ptr_newline = strchr (ptr_data, '\n');
+            ptr_data = (ptr_newline && (!ptr_space || (ptr_newline < ptr_space))) ?
+                ptr_newline : ptr_space;
             if (!ptr_data)
                 break;
             if (ptr_data < data + pos)
             {
-                while ((ptr_data < data + pos) && (ptr_data[0] == ' '))
+                while ((ptr_data < data + pos) && ((ptr_data[0] == ' ') || (ptr_data[0] == '\n')))
                 {
                     ptr_data++;
                 }
@@ -905,10 +910,10 @@ gui_completion_find_context (struct t_gui_completion *completion,
         pos_start = i;
         if (data[i] == ' ')
         {
-            if ((i > 0) && (data[i-1] != ' '))
+            if ((i > 0) && (data[i - 1] != ' ') && (data[i - 1] != '\n'))
             {
                 i--;
-                while ((i >= 0) && (data[i] != ' '))
+                while ((i >= 0) && (data[i] != ' ') && (data[i] != '\n'))
                 {
                     i--;
                 }
@@ -917,7 +922,7 @@ gui_completion_find_context (struct t_gui_completion *completion,
         }
         else
         {
-            while ((i >= 0) && (data[i] != ' '))
+            while ((i >= 0) && (data[i] != ' ') && (data[i] != '\n'))
             {
                 i--;
             }
@@ -932,7 +937,7 @@ gui_completion_find_context (struct t_gui_completion *completion,
         {
             /* base word stops after first space found (on or after cursor) */
             i = pos;
-            while ((i < size) && (data[i] != ' '))
+            while ((i < size) && (data[i] != ' ') && (data[i] != '\n'))
             {
                 i++;
             }
@@ -1144,7 +1149,6 @@ gui_completion_complete (struct t_gui_completion *completion)
     int length, word_found_seen, other_completion, partial_completion;
     int common_prefix_size, index, index2;
     struct t_gui_completion_word *ptr_completion_word, *ptr_completion_word2;
-    char *word_found_lower;
 
     length = utf8_strlen (completion->base_word);
     word_found_seen = 0;
@@ -1202,9 +1206,9 @@ gui_completion_complete (struct t_gui_completion *completion)
                                           ptr_completion_word->word,
                                           length) == 0))
             || (!ptr_completion_word->nick_completion
-                && (string_strncasecmp (completion->base_word,
-                                        ptr_completion_word->word,
-                                        length) == 0)))
+                && (string_strncmp (completion->base_word,
+                                    ptr_completion_word->word,
+                                    length) == 0)))
         {
             if ((!completion->word_found) || word_found_seen)
             {
@@ -1237,9 +1241,9 @@ gui_completion_complete (struct t_gui_completion *completion)
                                                       ptr_completion_word2->word,
                                                       length) == 0))
                         || (!ptr_completion_word->nick_completion
-                            && (string_strncasecmp (completion->base_word,
-                                                    ptr_completion_word2->word,
-                                                    length) == 0)))
+                            && (string_strncmp (completion->base_word,
+                                                ptr_completion_word2->word,
+                                                length) == 0)))
                     {
                         other_completion++;
                     }
@@ -1263,12 +1267,6 @@ gui_completion_complete (struct t_gui_completion *completion)
                     completion->word_found_is_nick = 0;
                     completion->add_space = 0;
                     completion->position = -1;
-                    word_found_lower = string_tolower (completion->word_found);
-                    if (word_found_lower)
-                    {
-                        free (completion->word_found);
-                        completion->word_found = word_found_lower;
-                    }
 
                     /* alert user of partial completion */
                     if (CONFIG_BOOLEAN(config_completion_partial_completion_alert))
@@ -1503,15 +1501,15 @@ const char *
 gui_completion_get_string (struct t_gui_completion *completion,
                            const char *property)
 {
-    if (completion)
-    {
-        if (string_strcasecmp (property, "base_command") == 0)
-            return completion->base_command;
-        else if (string_strcasecmp (property, "base_word") == 0)
-            return completion->base_word;
-        else if (string_strcasecmp (property, "args") == 0)
-            return completion->args;
-    }
+    if (!completion || !property)
+        return NULL;
+
+    if (strcmp (property, "base_command") == 0)
+        return completion->base_command;
+    else if (strcmp (property, "base_word") == 0)
+        return completion->base_word;
+    else if (strcmp (property, "args") == 0)
+        return completion->args;
 
     return NULL;
 }
