@@ -72,6 +72,8 @@ gui_focus_get_info (int x, int y)
                                   &focus_info->chat_line_x,
                                   &focus_info->chat_word,
                                   &focus_info->chat_focused_line,
+                                  &focus_info->chat_focused_line_bol,
+                                  &focus_info->chat_focused_line_eol,
                                   &focus_info->chat_bol,
                                   &focus_info->chat_eol);
 
@@ -102,6 +104,10 @@ gui_focus_free_info (struct t_gui_focus_info *focus_info)
         free (focus_info->chat_word);
     if (focus_info->chat_focused_line)
         free (focus_info->chat_focused_line);
+    if (focus_info->chat_focused_line_bol)
+        free (focus_info->chat_focused_line_bol);
+    if (focus_info->chat_focused_line_eol)
+        free (focus_info->chat_focused_line_eol);
     if (focus_info->chat_bol)
         free (focus_info->chat_bol);
     if (focus_info->chat_eol)
@@ -242,6 +248,8 @@ gui_focus_to_hashtable (struct t_gui_focus_info *focus_info, const char *key)
     }
     HASHTABLE_SET_STR_NOT_NULL("_chat_word", focus_info->chat_word);
     HASHTABLE_SET_STR_NOT_NULL("_chat_focused_line", focus_info->chat_focused_line);
+    HASHTABLE_SET_STR_NOT_NULL("_chat_focused_line_bol", focus_info->chat_focused_line_bol);
+    HASHTABLE_SET_STR_NOT_NULL("_chat_focused_line_eol", focus_info->chat_focused_line_eol);
     HASHTABLE_SET_STR_NOT_NULL("_chat_bol", focus_info->chat_bol);
     HASHTABLE_SET_STR_NOT_NULL("_chat_eol", focus_info->chat_eol);
 
