@@ -39,6 +39,7 @@ extern void gui_input_insert_string (struct t_gui_buffer *buffer,
                                      const char *string);
 extern void gui_input_clipboard_paste (struct t_gui_buffer *buffer);
 extern void gui_input_return (struct t_gui_buffer *buffer);
+extern void gui_input_split_return (struct t_gui_buffer *buffer);
 extern void gui_input_complete_next (struct t_gui_buffer *buffer);
 extern void gui_input_complete_previous (struct t_gui_buffer *buffer);
 extern void gui_input_search_text_here (struct t_gui_buffer *buffer);
@@ -58,14 +59,21 @@ extern void gui_input_delete_previous_word_whitespace (struct t_gui_buffer *buff
 extern void gui_input_delete_next_word (struct t_gui_buffer *buffer);
 extern void gui_input_delete_beginning_of_line (struct t_gui_buffer *buffer);
 extern void gui_input_delete_end_of_line (struct t_gui_buffer *buffer);
+extern void gui_input_delete_beginning_of_input (struct t_gui_buffer *buffer);
+extern void gui_input_delete_end_of_input (struct t_gui_buffer *buffer);
 extern void gui_input_delete_line (struct t_gui_buffer *buffer);
+extern void gui_input_delete_input (struct t_gui_buffer *buffer);
 extern void gui_input_transpose_chars (struct t_gui_buffer *buffer);
 extern void gui_input_move_beginning_of_line (struct t_gui_buffer *buffer);
 extern void gui_input_move_end_of_line (struct t_gui_buffer *buffer);
+extern void gui_input_move_beginning_of_input (struct t_gui_buffer *buffer);
+extern void gui_input_move_end_of_input (struct t_gui_buffer *buffer);
 extern void gui_input_move_previous_char (struct t_gui_buffer *buffer);
 extern void gui_input_move_next_char (struct t_gui_buffer *buffer);
 extern void gui_input_move_previous_word (struct t_gui_buffer *buffer);
 extern void gui_input_move_next_word (struct t_gui_buffer *buffer);
+extern void gui_input_move_previous_line (struct t_gui_buffer *buffer);
+extern void gui_input_move_next_line (struct t_gui_buffer *buffer);
 extern void gui_input_history_local_previous (struct t_gui_buffer *buffer);
 extern void gui_input_history_local_next (struct t_gui_buffer *buffer);
 extern void gui_input_history_global_previous (struct t_gui_buffer *buffer);
