@@ -54,7 +54,9 @@ enum t_gui_key_focus
 
 struct t_gui_key
 {
-    char *key;                      /* key combo (ex: a, ^W, ^W^C, meta-a)  */
+    char *key;                      /* key name (eg: ctrl-w, meta-left)     */
+    char **chunks;                  /* key chunks (split on comma)          */
+    int chunks_count;               /* number of chunks                     */
     int area_type[2];               /* type of areas (for cursor/mouse)     */
     char *area_name[2];             /* name of areas (for cursor/mouse)     */
     char *area_key;                 /* key after area (after ":")           */
@@ -73,12 +75,14 @@ extern struct t_gui_key *last_gui_default_key[GUI_KEY_NUM_CONTEXTS];
 extern int gui_keys_count[GUI_KEY_NUM_CONTEXTS];
 extern int gui_default_keys_count[GUI_KEY_NUM_CONTEXTS];
 extern char *gui_key_context_string[GUI_KEY_NUM_CONTEXTS];
+extern int gui_key_debug;
 extern int gui_key_verbose;
-extern char gui_key_combo_buffer[];
+extern char gui_key_combo[];
 extern int gui_key_grab;
 extern int gui_key_grab_count;
 extern int *gui_key_buffer;
 extern int gui_key_buffer_size;
+extern int gui_key_last_key_pressed_sent;
 extern int gui_key_paste_pending;
 extern int gui_key_paste_bracketed;
 extern time_t gui_key_last_activity_time;
@@ -88,32 +92,41 @@ extern time_t gui_key_last_activity_time;
 extern void gui_key_init ();
 extern int gui_key_search_context (const char *context);
 extern void gui_key_grab_init (int grab_command, const char *delay);
-extern char *gui_key_get_internal_code (const char *key);
-extern char *gui_key_get_expanded_name (const char *key);
-extern int gui_key_is_safe (int context, const char *key);
+extern int gui_key_expand (const char *key,
+                           char **key_name, char **key_name_alias);
+extern char *gui_key_legacy_to_alias (const char *key);
 extern struct t_gui_key *gui_key_new (struct t_gui_buffer *buffer,
                                       int context,
                                       const char *key,
-                                      const char *command);
+                                      const char *command,
+                                      int create_option);
 extern struct t_gui_key *gui_key_search (struct t_gui_key *keys,
                                          const char *key);
 extern struct t_gui_key *gui_key_bind (struct t_gui_buffer *buffer,
                                        int context,
                                        const char *key,
-                                       const char *command);
+                                       const char *command,
+                                       int check_key);
 extern int gui_key_bind_plugin (const char *context, struct t_hashtable *keys);
 extern int gui_key_unbind (struct t_gui_buffer *buffer, int context,
                            const char *key);
 extern int gui_key_unbind_plugin (const char *context, const char *key);
 extern int gui_key_focus (const char *key, int context);
+extern void gui_key_debug_print_key (const char *combo, const char *key_name,
+                                     const char *key_name_alias,
+                                     const char *command, int mouse);
 extern int gui_key_pressed (const char *key_str);
-extern void gui_key_free (struct t_gui_key **keys,
+extern void gui_key_free (int context,
+                          struct t_gui_key **keys,
                           struct t_gui_key **last_key,
                           int *keys_count,
-                          struct t_gui_key *key);
-extern void gui_key_free_all (struct t_gui_key **keys,
+                          struct t_gui_key *key,
+                          int delete_option);
+extern void gui_key_free_all (int context,
+                              struct t_gui_key **keys,
                               struct t_gui_key **last_key,
-                              int *keys_count);
+                              int *keys_count,
+                              int delete_option);
 extern void gui_key_buffer_reset ();
 extern void gui_key_buffer_add (unsigned char key);
 extern int gui_key_buffer_search (int start_index, int max_index,
@@ -122,6 +135,7 @@ extern void gui_key_buffer_remove (int index, int number);
 extern void gui_key_paste_remove_newline ();
 extern void gui_key_paste_replace_tabs ();
 extern void gui_key_paste_start ();
+extern void gui_key_paste_finish ();
 extern int gui_key_get_paste_lines ();
 extern int gui_key_paste_check (int bracketed_paste);
 extern void gui_key_paste_bracketed_timer_remove ();
@@ -140,6 +154,6 @@ extern void gui_key_print_log (struct t_gui_buffer *buffer);
 
 /* key functions (GUI dependent) */
 
-extern void gui_key_default_bindings (int context);
+extern void gui_key_default_bindings (int context, int create_option);
 
 #endif /* WEECHAT_GUI_KEY_H */
