@@ -30,14 +30,15 @@
 
 
 struct t_gui_bar_item *buflist_bar_item_buflist[BUFLIST_BAR_NUM_ITEMS] =
-{ NULL, NULL, NULL };
+{ NULL, NULL, NULL, NULL, NULL };
 struct t_hashtable *buflist_hashtable_pointers = NULL;
 struct t_hashtable *buflist_hashtable_extra_vars = NULL;
 struct t_hashtable *buflist_hashtable_options_conditions = NULL;
 struct t_arraylist *buflist_list_buffers[BUFLIST_BAR_NUM_ITEMS] =
-{ NULL, NULL, NULL };
+{ NULL, NULL, NULL, NULL, NULL };
 
-int old_line_number_current_buffer[BUFLIST_BAR_NUM_ITEMS] = { -1, -1, -1 };
+int old_line_number_current_buffer[BUFLIST_BAR_NUM_ITEMS] =
+{ -1, -1, -1, -1, -1 };
 
 
 /*
@@ -104,24 +105,34 @@ buflist_bar_item_get_index_with_pointer (struct t_gui_bar_item *item)
 /*
  * Updates buflist bar item if buflist is enabled (or if force argument is 1).
  *
- * If force == 1, all used items are refreshed
- *   (according to option buflist.look.use_items).
+ * If index == -1, all bar items (or all bar items used) are refreshed,
+ * otherwise only this bar item is refreshed.
+ *
+ * If force == 1, all used items are refreshed (according to option
+ * buflist.look.use_items).
  * If force == 2, all items are refreshed.
  */
 
 void
-buflist_bar_item_update (int force)
+buflist_bar_item_update (int index, int force)
 {
     int i, num_items;
 
     if (force || weechat_config_boolean (buflist_config_look_enabled))
     {
-        num_items = (force == 2) ?
-            BUFLIST_BAR_NUM_ITEMS :
-            weechat_config_integer (buflist_config_look_use_items);
-        for (i = 0; i < num_items; i++)
+        if ((index >= 0) && (index < BUFLIST_BAR_NUM_ITEMS))
         {
-            weechat_bar_item_update (buflist_bar_item_get_name (i));
+            weechat_bar_item_update (buflist_bar_item_get_name (index));
+        }
+        else
+        {
+            num_items = (force == 2) ?
+                BUFLIST_BAR_NUM_ITEMS :
+                weechat_config_integer (buflist_config_look_use_items);
+            for (i = 0; i < num_items; i++)
+            {
+                weechat_bar_item_update (buflist_bar_item_get_name (i));
+            }
         }
     }
 }
@@ -313,7 +324,7 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
                                         "highlight" };
     const char indent_empty[1] = { '\0' };
     const char *ptr_lag, *ptr_item_name, *ptr_tls_version;
-    int item_index, num_buffers, is_channel, is_private;
+    int item_index, num_buffers, is_channel, is_private, is_list;
     int i, j, length_max_number, current_buffer, number, prev_number, priority;
     int rc, count, line_number, line_number_current_buffer;
     int hotlist_priority_number;
@@ -444,7 +455,8 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
         ptr_type = weechat_buffer_get_string (ptr_buffer, "localvar_type");
         is_channel = (ptr_type && (strcmp (ptr_type, "channel") == 0));
         is_private = (ptr_type && (strcmp (ptr_type, "private") == 0));
-        ptr_format_indent = (is_channel || is_private) ?
+        is_list = (ptr_type && (strcmp (ptr_type, "list") == 0));
+        ptr_format_indent = (is_channel || is_private || is_list) ?
             weechat_config_string (buflist_config_format_indent) : indent_empty;
 
         /* nick prefix */
