@@ -22,7 +22,7 @@
 
 #define BUFLIST_BAR_ITEM_NAME "buflist"
 
-#define BUFLIST_BAR_NUM_ITEMS 3
+#define BUFLIST_BAR_NUM_ITEMS 5
 
 struct t_gui_bar_item;
 
@@ -32,7 +32,7 @@ extern struct t_arraylist *buflist_list_buffers[BUFLIST_BAR_NUM_ITEMS];
 extern const char *buflist_bar_item_get_name (int index);
 extern int buflist_bar_item_get_index (const char *item_name);
 extern int buflist_bar_item_get_index_with_pointer (struct t_gui_bar_item *item);
-extern void buflist_bar_item_update (int force);
+extern void buflist_bar_item_update (int index, int force);
 extern int buflist_bar_item_init ();
 extern void buflist_bar_item_end ();
 
