@@ -37,7 +37,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Execution of external commands in WeeChat"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
-WEECHAT_PLUGIN_PRIORITY(14000);
+WEECHAT_PLUGIN_PRIORITY(EXEC_PLUGIN_PRIORITY);
 
 struct t_weechat_plugin *weechat_exec_plugin = NULL;
 
@@ -65,7 +65,7 @@ exec_search_color (const char *color)
 
     for (i = 0; i < EXEC_NUM_COLORS; i++)
     {
-        if (weechat_strcasecmp (exec_color_string[i], color) == 0)
+        if (strcmp (exec_color_string[i], color) == 0)
             return i;
     }
 
@@ -86,6 +86,9 @@ exec_search_by_id (const char *id)
     char *error;
     long number;
 
+    if (!id)
+        return NULL;
+
     error = NULL;
     number = strtol (id, &error, 10);
     if (!error || error[0])
@@ -376,12 +379,15 @@ exec_concat_output (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
                     int out, const char *text)
 {
     int length, new_size;
-    const char *ptr_text;
-    char *new_output, *pos, *line;
+    const char *ptr_text, *pos, *pos_next;
+    char *new_output, *line;
 
     ptr_text = text;
 
-    /* if output is not sent as hsignal, display lines (ending with '\n') */
+    /*
+     * if output is not sent as hsignal, display lines
+     * (ending with "\r\n" or "\n")
+     */
     if (!exec_cmd->hsignal)
     {
         ptr_text = text;
@@ -390,6 +396,9 @@ exec_concat_output (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
             pos = strchr (ptr_text, '\n');
             if (!pos)
                 break;
+            pos_next = pos + 1;
+            if ((pos > ptr_text) && (ptr_text[pos - ptr_text - 1] == '\r'))
+                pos--;
             if (exec_cmd->output_size[out] > 0)
             {
                 length = exec_cmd->output_size[out] + (pos - ptr_text) + 1;
@@ -415,7 +424,7 @@ exec_concat_output (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
             exec_cmd->output_size[out] = 0;
             exec_display_line (exec_cmd, buffer, out, line);
             free (line);
-            ptr_text = pos + 1;
+            ptr_text = pos_next;
         }
     }
 
@@ -723,8 +732,7 @@ exec_debug_dump_cb (const void *pointer, void *data,
     (void) signal;
     (void) type_data;
 
-    if (!signal_data
-        || (weechat_strcasecmp ((char *)signal_data, EXEC_PLUGIN_NAME) == 0))
+    if (!signal_data || (strcmp ((char *)signal_data, EXEC_PLUGIN_NAME) == 0))
     {
         weechat_log_printf ("");
         weechat_log_printf ("***** \"%s\" plugin dump *****",
