@@ -108,13 +108,13 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-bar") == 0)
+    if (weechat_strcmp (argv[1], "-bar") == 0)
     {
         fset_add_bar ();
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-refresh") == 0)
+    if (weechat_strcmp (argv[1], "-refresh") == 0)
     {
         fset_option_get_options ();
         fset_buffer_refresh (0);
@@ -122,7 +122,7 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-up") == 0)
+    if (weechat_strcmp (argv[1], "-up") == 0)
     {
         if (fset_buffer)
         {
@@ -143,7 +143,7 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-down") == 0)
+    if (weechat_strcmp (argv[1], "-down") == 0)
     {
         if (fset_buffer)
         {
@@ -164,7 +164,7 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-left") == 0)
+    if (weechat_strcmp (argv[1], "-left") == 0)
     {
         if (fset_buffer)
         {
@@ -188,7 +188,7 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-right") == 0)
+    if (weechat_strcmp (argv[1], "-right") == 0)
     {
         if (fset_buffer)
         {
@@ -212,13 +212,13 @@ fset_command_fset (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
-    if (weechat_strcasecmp (argv[1], "-go") == 0)
+    if (weechat_strcmp (argv[1], "-go") == 0)
     {
         if (fset_buffer)
         {
             if (argc < 3)
                 WEECHAT_COMMAND_ERROR;
-            if (weechat_strcasecmp (argv[2], "end") == 0)
+            if (weechat_strcmp (argv[2], "end") == 0)
                 line = weechat_arraylist_size (fset_options) - 1;
             else
                 line = fset_command_get_int_arg (argc, argv, 2, -1);
@@ -233,7 +233,7 @@ fset_command_fset (const void *pointer, void *data,
 
     if (argv[1][0] == '-')
     {
-        if (weechat_strcasecmp (argv[1], "-toggle") == 0)
+        if (weechat_strcmp (argv[1], "-toggle") == 0)
         {
             if (fset_option_count_marked > 0)
             {
@@ -257,7 +257,7 @@ fset_command_fset (const void *pointer, void *data,
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-add") == 0)
+        if (weechat_strcmp (argv[1], "-add") == 0)
         {
             value = fset_command_get_int_arg (argc, argv, 2, 0);
             if (value == 0)
@@ -282,7 +282,8 @@ fset_command_fset (const void *pointer, void *data,
                 fset_command_get_option (&ptr_fset_option, &ptr_option);
                 if (ptr_fset_option &&
                     ((ptr_fset_option->type == FSET_OPTION_TYPE_INTEGER)
-                     || (ptr_fset_option->type == FSET_OPTION_TYPE_COLOR)))
+                     || (ptr_fset_option->type == FSET_OPTION_TYPE_COLOR)
+                     || (ptr_fset_option->type == FSET_OPTION_TYPE_ENUM)))
                 {
                     fset_option_add_value (ptr_fset_option, ptr_option, value);
                 }
@@ -295,7 +296,7 @@ fset_command_fset (const void *pointer, void *data,
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-reset") == 0)
+        if (weechat_strcmp (argv[1], "-reset") == 0)
         {
             if (fset_option_count_marked > 0)
             {
@@ -319,7 +320,7 @@ fset_command_fset (const void *pointer, void *data,
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-unset") == 0)
+        if (weechat_strcmp (argv[1], "-unset") == 0)
         {
             if (fset_option_count_marked > 0)
             {
@@ -343,35 +344,35 @@ fset_command_fset (const void *pointer, void *data,
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-set") == 0)
+        if (weechat_strcmp (argv[1], "-set") == 0)
         {
             fset_command_get_option (&ptr_fset_option, &ptr_option);
             fset_option_set (ptr_fset_option, ptr_option, buffer, 0);
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-setnew") == 0)
+        if (weechat_strcmp (argv[1], "-setnew") == 0)
         {
             fset_command_get_option (&ptr_fset_option, &ptr_option);
             fset_option_set (ptr_fset_option, ptr_option, buffer, -1);
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-append") == 0)
+        if (weechat_strcmp (argv[1], "-append") == 0)
         {
             fset_command_get_option (&ptr_fset_option, &ptr_option);
             fset_option_set (ptr_fset_option, ptr_option, buffer, 1);
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-mark") == 0)
+        if (weechat_strcmp (argv[1], "-mark") == 0)
         {
             fset_command_get_option (&ptr_fset_option, &ptr_option);
             fset_option_toggle_mark (ptr_fset_option, ptr_option);
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-format") == 0)
+        if (weechat_strcmp (argv[1], "-format") == 0)
         {
             min = weechat_hdata_integer (fset_hdata_config_option,
                                          fset_config_look_format_number,
@@ -388,20 +389,20 @@ fset_command_fset (const void *pointer, void *data,
             return WEECHAT_RC_OK;
         }
 
-        if (weechat_strcasecmp (argv[1], "-export") == 0)
+        if (weechat_strcmp (argv[1], "-export") == 0)
         {
             if (argc < 3)
                 WEECHAT_COMMAND_ERROR;
             with_help = weechat_config_boolean (fset_config_look_export_help_default);
             ptr_filename = argv_eol[2];
-            if (weechat_strcasecmp (argv[2], "-help") == 0)
+            if (weechat_strcmp (argv[2], "-help") == 0)
             {
                 with_help = 1;
                 if (argc < 4)
                     WEECHAT_COMMAND_ERROR;
                 ptr_filename = argv_eol[3];
             }
-            else if (weechat_strcasecmp (argv[2], "-nohelp") == 0)
+            else if (weechat_strcmp (argv[2], "-nohelp") == 0)
             {
                 with_help = 0;
                 if (argc < 4)
@@ -454,7 +455,6 @@ fset_command_run_set_cb (const void *pointer, void *data,
     /* make C compiler happy */
     (void) pointer;
     (void) data;
-    (void) buffer;
 
     /* ignore /set command if issued on fset buffer */
     if (fset_buffer && (buffer == fset_buffer))
@@ -483,8 +483,8 @@ fset_command_run_set_cb (const void *pointer, void *data,
      * (we must not catch that in fset!)
      */
     if ((argc > 1)
-        && ((weechat_strcasecmp (argv[1], "diff") == 0)
-            || (weechat_strcasecmp (argv[1], "env") == 0)))
+        && ((weechat_strcmp (argv[1], "diff") == 0)
+            || (weechat_strcmp (argv[1], "env") == 0)))
     {
         goto end;
     }
@@ -575,6 +575,44 @@ end:
     return rc;
 }
 
+/*
+ * Hooks execution of command "/key".
+ */
+
+int
+fset_command_run_key_cb (const void *pointer, void *data,
+                         struct t_gui_buffer *buffer, const char *command)
+{
+    const char *ptr_args;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) buffer;
+
+    if (strncmp (command, "/key", 4) != 0)
+        return WEECHAT_RC_OK;
+
+    ptr_args = strchr (command,  ' ');
+    while (ptr_args && (ptr_args[0] == ' '))
+    {
+        ptr_args++;
+    }
+
+    if (!ptr_args || !ptr_args[0])
+    {
+        fset_option_filter_options ("weechat.key*");
+        if (!fset_buffer)
+            fset_buffer_open ();
+        fset_buffer_set_localvar_filter ();
+        fset_buffer_refresh (1);
+        weechat_buffer_set (fset_buffer, "display", "1");
+        return WEECHAT_RC_OK_EAT;
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Hooks fset commands.
  */
@@ -585,6 +623,7 @@ fset_command_init ()
     weechat_hook_command (
         "fset",
         N_("fast set WeeChat and plugins options"),
+        /* TRANSLATORS: only text between angle brackets (eg: "<name>") must be translated */
         N_("-bar"
            " || -refresh"
            " || -up|-down [<number>]"
@@ -614,7 +653,7 @@ fset_command_init ()
            "(\"end\" to select the last line)\n"
            "    -toggle: toggle the boolean value\n"
            "       -add: add \"value\" (which can be a negative number) "
-           "for integers and colors, set/append to value for other types "
+           "for integers, colors and enums, set/append to value for other types "
            "(set for a negative value, append for a positive value)\n"
            "     -reset: reset the value of option\n"
            "     -unset: unset the option\n"
@@ -638,7 +677,8 @@ fset_command_init ()
            "               *       show all options (no filter)\n"
            "               xxx     show only options with \"xxx\" in name\n"
            "               f:xxx   show only configuration file \"xxx\"\n"
-           "               t:xxx   show only type \"xxx\" (bool/int/str/col)\n"
+           "               t:xxx   show only type \"xxx\" (bool/int/str/col/enum "
+           "or boolean/integer/string/color/enum)\n"
            "               d       show only changed options\n"
            "               d:xxx   show only changed options with \"xxx\" in "
            "name\n"
@@ -655,10 +695,10 @@ fset_command_init ()
            "               c:xxx   show only options matching the evaluated "
            "condition \"xxx\", using following variables: file, section, "
            "option, name, parent_name, type, type_en, type_short "
-           "(bool/int/str/col), type_tiny (b/i/s/c), default_value, "
+           "(bool/int/str/col/enum), type_tiny (b/i/s/c/e), default_value, "
            "default_value_undef, value, quoted_value, value_undef, "
            "value_changed, parent_value, min, max, description, description2, "
-           "description_en, description_en2, string_values\n"
+           "description_en, description_en2, string_values, allowed_values\n"
            "\n"
            "The lines with options are displayed using string evaluation "
            "(see /help eval for the format), with these options:\n"
@@ -675,8 +715,8 @@ fset_command_init ()
            "    - ${parent_name}: parent option name\n"
            "    - ${type}: option type (translated)\n"
            "    - ${type_en}: option type (in English)\n"
-           "    - ${type_short}: short option type (bool/int/str/col)\n"
-           "    - ${type_tiny}: tiny option type (b/i/s/c)\n"
+           "    - ${type_short}: short option type (bool/int/str/col/enum)\n"
+           "    - ${type_tiny}: tiny option type (b/i/s/c/e)\n"
            "    - ${default_value}: option default value\n"
            "    - ${default_value_undef}: \"1\" if default value is null, "
            "otherwise \"0\"\n"
@@ -694,8 +734,9 @@ fset_command_init ()
            "    - ${description_en}: option description (in English)\n"
            "    - ${description_en2}: option description (in English), "
            "\"(no description)\" if there's no description\n"
-           "    - ${string_values}: string values allowed for set of an "
-           "integer option using strings\n"
+           "    - ${string_values}: string values allowed for set of an enum "
+           "option\n"
+           "    - ${allowed_values}: allowed values\n"
            "    - ${marked}: \"1\" if option is marked, otherwise \"0\"\n"
            "    - ${index}: index of option in list\n"
            "  - option data, with color but no spaces:\n"
@@ -725,10 +766,10 @@ fset_command_init ()
            "\n"
            "Keys and input to set options on fset buffer:\n"
            "  alt+space         t       toggle boolean value\n"
-           "  alt+'-'           -       subtract 1 from value for integer/color, "
-           "set value for other types\n"
-           "  alt+'+'           +       add 1 to value for integer/color, append "
-           "to value for other types\n"
+           "  alt+'-'           -       subtract 1 from value for "
+           "integer/color/enum, set value for other types\n"
+           "  alt+'+'           +       add 1 to value for integer/color/enum, "
+           "append to value for other types\n"
            "  alt+f, alt+r      r       reset value\n"
            "  alt+f, alt+u      u       unset value\n"
            "  alt+enter         s       set value\n"
@@ -745,7 +786,7 @@ fset_command_init ()
            "see filters above)\n"
            "\n"
            "Other keys and input on fset buffer:\n"
-           "  ctrl+L                    refresh options and whole screen "
+           "  ctrl+l                    refresh options and whole screen "
            "(command: /fset -refresh)\n"
            "                    $       refresh options (keep marked options)\n"
            "                    $$      refresh options (unmark all options)\n"
@@ -753,13 +794,13 @@ fset_command_init ()
            "(plugins.desc.*)\n"
            "  alt+v             v       toggle help bar\n"
            "                    s:x,y   sort options by fields x,y "
-           "(see /help fset.look.sort)\n"
+           "(see above)\n"
            "                    s:      reset sort to its default value "
-           "(see /help fset.look.sort)\n"
+           "(see above)\n"
            "                    w:xxx   export options in file \"xxx\"\n"
            "                    w-:xxx  export options in file \"xxx\" without help\n"
            "                    w+:xxx  export options in file \"xxx\" with help\n"
-           "  ctrl+X            x       switch the format used to display options\n"
+           "  ctrl+x            x       switch the format used to display options\n"
            "                    q       close fset buffer\n"
            "\n"
            "Mouse actions on fset buffer:\n"
@@ -768,7 +809,7 @@ fset_command_init ()
            "  right button                    toggle boolean (on/off) or "
            "edit the option value\n"
            "  right button + drag left/right  increase/decrease value "
-           "for integer/color, set/append to value for other types\n"
+           "for integer/color/enum, set/append to value for other types\n"
            "  right button + drag up/down     mark/unmark multiple options\n"
            "\n"
            "Note: if input has one or more leading spaces, the following text "
@@ -807,4 +848,5 @@ fset_command_init ()
         " || *|c:|f:|s:|d|d:|d=|d==|=|==|%(fset_options)",
         &fset_command_fset, NULL, NULL);
     weechat_hook_command_run ("/set", &fset_command_run_set_cb, NULL, NULL);
+    weechat_hook_command_run ("/key", &fset_command_run_key_cb, NULL, NULL);
 }
