@@ -63,6 +63,7 @@ struct t_config_option *fset_config_format_option[2] = { NULL, NULL };
 
 /* fset config, color section */
 
+struct t_config_option *fset_config_color_allowed_values[2] = { NULL, NULL };
 struct t_config_option *fset_config_color_color_name[2] = { NULL, NULL };
 struct t_config_option *fset_config_color_default_value[2] = { NULL, NULL };
 struct t_config_option *fset_config_color_description[2] = { NULL, NULL };
@@ -255,7 +256,7 @@ fset_config_change_use_keys_cb (const void *pointer, void *data,
     (void) option;
 
     if (fset_buffer)
-        fset_buffer_set_keys ();
+        fset_buffer_set_keys (NULL);
 }
 
 /*
@@ -584,8 +585,8 @@ fset_config_init ()
             NULL, 0, 0,
             "${marked} ${name}  ${type}  ${value2}${newline}"
             "  ${empty_name}  ${_default_value}${color:244} -- "
-            "${min}..${max}${newline}"
-            "  ${empty_name}  ${description}",
+            "${_allowed_values}${newline}"
+            "  ${empty_name}  ${_description}",
             NULL, 0,
             NULL, NULL, NULL,
             &fset_config_change_format_cb, NULL, NULL,
@@ -603,6 +604,22 @@ fset_config_init ()
         NULL, NULL, NULL);
     if (fset_config_section_color)
     {
+        fset_config_color_allowed_values[0] = weechat_config_new_option (
+            fset_config_file, fset_config_section_color,
+            "allowed_values", "color",
+            N_("color for allowed values"),
+            NULL, 0, 0, "default", NULL, 0,
+            NULL, NULL, NULL,
+            &fset_config_change_color_cb, NULL, NULL,
+            NULL, NULL, NULL);
+        fset_config_color_allowed_values[1] = weechat_config_new_option (
+            fset_config_file, fset_config_section_color,
+            "allowed_values_selected", "color",
+            N_("color for allowed values on the selected line"),
+            NULL, 0, 0, "white", NULL, 0,
+            NULL, NULL, NULL,
+            &fset_config_change_color_cb, NULL, NULL,
+            NULL, NULL, NULL);
         fset_config_color_color_name[0] = weechat_config_new_option (
             fset_config_file, fset_config_section_color,
             "color_name", "color",
