@@ -30,6 +30,7 @@ enum t_fset_option_type
     FSET_OPTION_TYPE_INTEGER,
     FSET_OPTION_TYPE_STRING,
     FSET_OPTION_TYPE_COLOR,
+    FSET_OPTION_TYPE_ENUM,
     /* number of option types */
     FSET_OPTION_NUM_TYPES,
 };
@@ -50,6 +51,7 @@ struct t_fset_option
     char *max;                           /* max value                       */
     char *description;                   /* option description              */
     char *string_values;                 /* string values for option        */
+    char *allowed_values;                /* allowed values (depends on type)*/
     int marked;                          /* option marked for group oper.   */
     struct t_fset_option *prev_option;   /* link to previous option         */
     struct t_fset_option *next_option;   /* link to next option             */
@@ -77,6 +79,7 @@ struct t_fset_option_max_length
     int description_en;
     int description_en2;
     int string_values;
+    int allowed_values;
     int marked;
 };
 
