@@ -1,7 +1,7 @@
 /*
  * irc-completion.c - completion for IRC commands
  *
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -31,6 +31,7 @@
 #include "irc-completion.h"
 #include "irc-config.h"
 #include "irc-ignore.h"
+#include "irc-join.h"
 #include "irc-modelist.h"
 #include "irc-nick.h"
 #include "irc-notify.h"
@@ -56,8 +57,8 @@ irc_completion_server_cb (const void *pointer, void *data,
 
     if (ptr_server)
     {
-        weechat_hook_completion_list_add (completion, ptr_server->name,
-                                          0, WEECHAT_LIST_POS_SORT);
+        weechat_completion_list_add (completion, ptr_server->name,
+                                     0, WEECHAT_LIST_POS_SORT);
     }
 
     return WEECHAT_RC_OK;
@@ -82,8 +83,8 @@ irc_completion_server_nick_cb (const void *pointer, void *data,
 
     if (ptr_server && ptr_server->nick)
     {
-        weechat_hook_completion_list_add (completion, ptr_server->nick,
-                                          1, WEECHAT_LIST_POS_SORT);
+        weechat_completion_list_add (completion, ptr_server->nick,
+                                     1, WEECHAT_LIST_POS_SORT);
     }
 
     return WEECHAT_RC_OK;
@@ -115,16 +116,16 @@ irc_completion_server_channels_cb (const void *pointer, void *data,
         {
             if (ptr_channel2->type == IRC_CHANNEL_TYPE_CHANNEL)
             {
-                weechat_hook_completion_list_add (completion, ptr_channel2->name,
-                                                  0, WEECHAT_LIST_POS_SORT);
+                weechat_completion_list_add (completion, ptr_channel2->name,
+                                             0, WEECHAT_LIST_POS_SORT);
             }
         }
 
         /* add current channel first in list */
         if (ptr_channel)
         {
-            weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                              0, WEECHAT_LIST_POS_BEGINNING);
+            weechat_completion_list_add (completion, ptr_channel->name,
+                                         0, WEECHAT_LIST_POS_BEGINNING);
         }
     }
 
@@ -157,8 +158,8 @@ irc_completion_server_privates_cb (const void *pointer, void *data,
         {
             if (ptr_channel->type == IRC_CHANNEL_TYPE_PRIVATE)
             {
-                weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                                  0, WEECHAT_LIST_POS_SORT);
+                weechat_completion_list_add (completion, ptr_channel->name,
+                                             0, WEECHAT_LIST_POS_SORT);
             }
         }
     }
@@ -196,20 +197,59 @@ irc_completion_server_nicks_cb (const void *pointer, void *data,
                 for (ptr_nick = ptr_channel2->nicks; ptr_nick;
                      ptr_nick = ptr_nick->next_nick)
                 {
-                    weechat_hook_completion_list_add (completion, ptr_nick->name,
-                                                      1, WEECHAT_LIST_POS_SORT);
+                    weechat_completion_list_add (completion, ptr_nick->name,
+                                                 1, WEECHAT_LIST_POS_SORT);
                 }
             }
         }
 
         /* add self nick at the end */
-        weechat_hook_completion_list_add (completion, ptr_server->nick,
-                                          1, WEECHAT_LIST_POS_END);
+        weechat_completion_list_add (completion, ptr_server->nick,
+                                     1, WEECHAT_LIST_POS_END);
     }
 
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds prefix modes filters to completion list.
+ */
+
+int
+irc_completion_server_prefix_modes_filter_cb (const void *pointer, void *data,
+                                              const char *completion_item,
+                                              struct t_gui_buffer *buffer,
+                                              struct t_gui_completion *completion)
+{
+    const char *ptr_prefix_modes;
+    char str_filter[16];
+    int i;
+
+    IRC_BUFFER_GET_SERVER_CHANNEL(buffer);
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+
+    ptr_prefix_modes = irc_server_get_prefix_modes (ptr_server);
+    if (!ptr_prefix_modes)
+        return WEECHAT_RC_OK;
+
+    for (i = 0; ptr_prefix_modes[i]; i++)
+    {
+        snprintf (str_filter, sizeof (str_filter), "-%c", ptr_prefix_modes[i]);
+        weechat_completion_list_add (completion, str_filter,
+                                     1, WEECHAT_LIST_POS_END);
+    }
+
+    /* add filter on regular users at the end */
+    weechat_completion_list_add (completion, "-*",
+                                 1, WEECHAT_LIST_POS_END);
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds servers to completion list.
  */
@@ -231,8 +271,8 @@ irc_completion_servers_cb (const void *pointer, void *data,
     for (ptr_server = irc_servers; ptr_server;
          ptr_server = ptr_server->next_server)
     {
-        weechat_hook_completion_list_add (completion, ptr_server->name,
-                                          0, WEECHAT_LIST_POS_SORT);
+        weechat_completion_list_add (completion, ptr_server->name,
+                                     0, WEECHAT_LIST_POS_SORT);
     }
 
     return WEECHAT_RC_OK;
@@ -257,8 +297,8 @@ irc_completion_channel_cb (const void *pointer, void *data,
 
     if (ptr_channel)
     {
-        weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                          0, WEECHAT_LIST_POS_SORT);
+        weechat_completion_list_add (completion, ptr_channel->name,
+                                     0, WEECHAT_LIST_POS_SORT);
     }
 
     return WEECHAT_RC_OK;
@@ -286,10 +326,10 @@ irc_completion_channel_nicks_add_speakers (struct t_gui_completion *completion,
                 weechat_list_get (channel->nicks_speaking[highlight], i));
             if (nick && irc_nick_search (server, channel, nick))
             {
-                weechat_hook_completion_list_add (completion,
-                                                  nick,
-                                                  1,
-                                                  WEECHAT_LIST_POS_BEGINNING);
+                weechat_completion_list_add (completion,
+                                             nick,
+                                             1,
+                                             WEECHAT_LIST_POS_BEGINNING);
             }
         }
     }
@@ -322,38 +362,38 @@ irc_completion_channel_nicks_cb (const void *pointer, void *data,
                 for (ptr_nick = ptr_channel->nicks; ptr_nick;
                      ptr_nick = ptr_nick->next_nick)
                 {
-                    weechat_hook_completion_list_add (completion,
-                                                      ptr_nick->name,
-                                                      1,
-                                                      WEECHAT_LIST_POS_SORT);
+                    weechat_completion_list_add (completion,
+                                                 ptr_nick->name,
+                                                 1,
+                                                 WEECHAT_LIST_POS_SORT);
                 }
                 /* add recent speakers on channel */
-                if (weechat_config_integer (irc_config_look_nick_completion_smart) == IRC_CONFIG_NICK_COMPLETION_SMART_SPEAKERS)
+                if (weechat_config_enum (irc_config_look_nick_completion_smart) == IRC_CONFIG_NICK_COMPLETION_SMART_SPEAKERS)
                 {
                     irc_completion_channel_nicks_add_speakers (completion, ptr_server, ptr_channel, 0);
                 }
                 /* add nicks whose make highlights on me recently on this channel */
-                if (weechat_config_integer (irc_config_look_nick_completion_smart) == IRC_CONFIG_NICK_COMPLETION_SMART_SPEAKERS_HIGHLIGHTS)
+                if (weechat_config_enum (irc_config_look_nick_completion_smart) == IRC_CONFIG_NICK_COMPLETION_SMART_SPEAKERS_HIGHLIGHTS)
                 {
                     irc_completion_channel_nicks_add_speakers (completion, ptr_server, ptr_channel, 1);
                 }
                 /* add self nick at the end */
-                weechat_hook_completion_list_add (completion,
-                                                  ptr_server->nick,
-                                                  1,
-                                                  WEECHAT_LIST_POS_END);
+                weechat_completion_list_add (completion,
+                                             ptr_server->nick,
+                                             1,
+                                             WEECHAT_LIST_POS_END);
                 break;
             case IRC_CHANNEL_TYPE_PRIVATE:
                 /* remote nick */
-                weechat_hook_completion_list_add (completion,
-                                                  ptr_channel->name,
-                                                  1,
-                                                  WEECHAT_LIST_POS_SORT);
+                weechat_completion_list_add (completion,
+                                             ptr_channel->name,
+                                             1,
+                                             WEECHAT_LIST_POS_SORT);
                 /* add self nick at the end */
-                weechat_hook_completion_list_add (completion,
-                                                  ptr_server->nick,
-                                                  1,
-                                                  WEECHAT_LIST_POS_END);
+                weechat_completion_list_add (completion,
+                                             ptr_server->nick,
+                                             1,
+                                             WEECHAT_LIST_POS_END);
                 break;
         }
         ptr_channel->nick_completion_reset = 0;
@@ -391,10 +431,10 @@ irc_completion_channel_nicks_hosts_cb (const void *pointer, void *data,
                 for (ptr_nick = ptr_channel->nicks; ptr_nick;
                      ptr_nick = ptr_nick->next_nick)
                 {
-                    weechat_hook_completion_list_add (completion,
-                                                      ptr_nick->name,
-                                                      1,
-                                                      WEECHAT_LIST_POS_SORT);
+                    weechat_completion_list_add (completion,
+                                                 ptr_nick->name,
+                                                 1,
+                                                 WEECHAT_LIST_POS_SORT);
                     if (ptr_nick->host)
                     {
                         length = strlen (ptr_nick->name) + 1 +
@@ -404,7 +444,7 @@ irc_completion_channel_nicks_hosts_cb (const void *pointer, void *data,
                         {
                             snprintf (buf, length, "%s!%s",
                                       ptr_nick->name, ptr_nick->host);
-                            weechat_hook_completion_list_add (
+                            weechat_completion_list_add (
                                 completion, buf, 0, WEECHAT_LIST_POS_SORT);
                             free (buf);
                         }
@@ -412,7 +452,7 @@ irc_completion_channel_nicks_hosts_cb (const void *pointer, void *data,
                 }
                 break;
             case IRC_CHANNEL_TYPE_PRIVATE:
-                weechat_hook_completion_list_add (
+                weechat_completion_list_add (
                     completion, ptr_channel->name, 1, WEECHAT_LIST_POS_SORT);
                 break;
         }
@@ -453,9 +493,9 @@ irc_completion_modelist_masks_cb (const void *pointer, void *data,
             for (ptr_item = ptr_modelist->items; ptr_item;
                  ptr_item = ptr_item->next_item)
             {
-                weechat_hook_completion_list_add (completion,
-                                                  ptr_item->mask,
-                                                  0, WEECHAT_LIST_POS_END);
+                weechat_completion_list_add (completion,
+                                             ptr_item->mask,
+                                             0, WEECHAT_LIST_POS_END);
             }
         }
     }
@@ -497,9 +537,9 @@ irc_completion_modelist_numbers_cb (const void *pointer, void *data,
             {
                 snprintf (str_number, sizeof (str_number),
                           "%d", ptr_item->number + 1);
-                weechat_hook_completion_list_add (completion,
-                                                  str_number,
-                                                  0, WEECHAT_LIST_POS_END);
+                weechat_completion_list_add (completion,
+                                             str_number,
+                                             0, WEECHAT_LIST_POS_END);
             }
         }
     }
@@ -531,7 +571,7 @@ irc_completion_channel_topic_cb (const void *pointer, void *data,
     {
         if (irc_server_strncasecmp (ptr_server, ptr_channel->topic,
                                     ptr_channel->name,
-                                    strlen (ptr_channel->name)) == 0)
+                                    weechat_utf8_strlen (ptr_channel->name)) == 0)
         {
             /*
              * if topic starts with channel name, add another channel name
@@ -551,9 +591,9 @@ irc_completion_channel_topic_cb (const void *pointer, void *data,
         else
             topic = strdup (ptr_channel->topic);
 
-        weechat_hook_completion_list_add (completion,
-                                          (topic) ? topic : ptr_channel->topic,
-                                          0, WEECHAT_LIST_POS_SORT);
+        weechat_completion_list_add (completion,
+                                     (topic) ? topic : ptr_channel->topic,
+                                     0, WEECHAT_LIST_POS_SORT);
         if (topic)
             free (topic);
     }
@@ -603,10 +643,10 @@ irc_completion_channels_cb (const void *pointer, void *data,
                 }
                 else
                 {
-                    weechat_hook_completion_list_add (completion,
-                                                      ptr_channel2->name,
-                                                      0,
-                                                      WEECHAT_LIST_POS_SORT);
+                    weechat_completion_list_add (completion,
+                                                 ptr_channel2->name,
+                                                 0,
+                                                 WEECHAT_LIST_POS_SORT);
                 }
             }
         }
@@ -615,7 +655,7 @@ irc_completion_channels_cb (const void *pointer, void *data,
     /* add channels of current server first in list */
     for (i = weechat_list_size (channels_current_server) - 1; i >= 0; i--)
     {
-        weechat_hook_completion_list_add (
+        weechat_completion_list_add (
             completion,
             weechat_list_string (
                 weechat_list_get (channels_current_server, i)),
@@ -627,13 +667,61 @@ irc_completion_channels_cb (const void *pointer, void *data,
     /* add current channel first in list */
     if (ptr_channel)
     {
-        weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                          0, WEECHAT_LIST_POS_BEGINNING);
+        weechat_completion_list_add (completion, ptr_channel->name,
+                                     0, WEECHAT_LIST_POS_BEGINNING);
     }
 
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds channels automatically joined on the current server
+ * (option "autojoin").
+ */
+
+int
+irc_completion_channels_autojoin_cb (const void *pointer, void *data,
+                                     const char *completion_item,
+                                     struct t_gui_buffer *buffer,
+                                     struct t_gui_completion *completion)
+{
+    struct t_arraylist *arraylist;
+    struct t_irc_join_channel *ptr_join_chan;
+    int i, size;
+
+    IRC_BUFFER_GET_SERVER(buffer);
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+
+    if (!ptr_server)
+        return WEECHAT_RC_OK;
+
+    arraylist = irc_join_split (
+        ptr_server,
+        IRC_SERVER_OPTION_STRING(ptr_server, IRC_SERVER_OPTION_AUTOJOIN),
+        0);
+    if (!arraylist)
+        return WEECHAT_RC_OK;
+
+    size = weechat_arraylist_size (arraylist);
+    for (i = 0; i < size; i++)
+    {
+        ptr_join_chan = (struct t_irc_join_channel *)weechat_arraylist_get (
+            arraylist, i);
+        weechat_completion_list_add (completion,
+                                     ptr_join_chan->name,
+                                     0,
+                                     WEECHAT_LIST_POS_END);
+    }
+
+    weechat_arraylist_free (arraylist);
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds privates of all servers to completion list.
  */
@@ -661,8 +749,8 @@ irc_completion_privates_cb (const void *pointer, void *data,
         {
             if (ptr_channel->type == IRC_CHANNEL_TYPE_PRIVATE)
             {
-                weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                                  0, WEECHAT_LIST_POS_SORT);
+                weechat_completion_list_add (completion, ptr_channel->name,
+                                             0, WEECHAT_LIST_POS_SORT);
             }
         }
     }
@@ -695,8 +783,8 @@ irc_completion_msg_kick_cb (const void *pointer, void *data,
                                             IRC_SERVER_OPTION_MSG_KICK);
         if (msg_kick && msg_kick[0])
         {
-            weechat_hook_completion_list_add (completion, msg_kick,
-                                              0, WEECHAT_LIST_POS_SORT);
+            weechat_completion_list_add (completion, msg_kick,
+                                         0, WEECHAT_LIST_POS_SORT);
         }
     }
 
@@ -728,8 +816,8 @@ irc_completion_msg_part_cb (const void *pointer, void *data,
                                             IRC_SERVER_OPTION_MSG_PART);
         if (msg_part && msg_part[0])
         {
-            weechat_hook_completion_list_add (completion, msg_part,
-                                              0, WEECHAT_LIST_POS_SORT);
+            weechat_completion_list_add (completion, msg_part,
+                                         0, WEECHAT_LIST_POS_SORT);
         }
     }
 
@@ -759,8 +847,8 @@ irc_completion_ignores_numbers_cb (const void *pointer, void *data,
          ptr_ignore = ptr_ignore->next_ignore)
     {
         snprintf (str_number, sizeof (str_number), "%d", ptr_ignore->number);
-        weechat_hook_completion_list_add (completion, str_number,
-                                          0, WEECHAT_LIST_POS_END);
+        weechat_completion_list_add (completion, str_number,
+                                     0, WEECHAT_LIST_POS_END);
     }
 
     return WEECHAT_RC_OK;
@@ -790,8 +878,8 @@ irc_completion_notify_nicks_cb (const void *pointer, void *data,
         for (ptr_notify = ptr_server->notify_list; ptr_notify;
              ptr_notify = ptr_notify->next_notify)
         {
-            weechat_hook_completion_list_add (completion, ptr_notify->nick,
-                                              0, WEECHAT_LIST_POS_SORT);
+            weechat_completion_list_add (completion, ptr_notify->nick,
+                                         0, WEECHAT_LIST_POS_SORT);
         }
     }
     else
@@ -802,8 +890,8 @@ irc_completion_notify_nicks_cb (const void *pointer, void *data,
             for (ptr_notify = ptr_server->notify_list; ptr_notify;
                  ptr_notify = ptr_notify->next_notify)
             {
-                weechat_hook_completion_list_add (completion, ptr_notify->nick,
-                                                  0, WEECHAT_LIST_POS_SORT);
+                weechat_completion_list_add (completion, ptr_notify->nick,
+                                             0, WEECHAT_LIST_POS_SORT);
             }
         }
     }
@@ -811,6 +899,62 @@ irc_completion_notify_nicks_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds filters for raw buffer to completion list.
+ */
+
+int
+irc_completion_raw_filters_cb (const void *pointer, void *data,
+                               const char *completion_item,
+                               struct t_gui_buffer *buffer,
+                               struct t_gui_completion *completion)
+{
+    char str_filter[1024];
+
+    IRC_BUFFER_GET_SERVER(buffer);
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+
+    /* all messages */
+    weechat_completion_list_add (completion, "*",
+                                 0, WEECHAT_LIST_POS_SORT);
+
+    /* condition */
+    weechat_completion_list_add (completion,
+                                 "c:${recv} && ${command}==PRIVMSG",
+                                 0, WEECHAT_LIST_POS_SORT);
+
+    /* message flag */
+    weechat_completion_list_add (completion, "f:modified",
+                                 0, WEECHAT_LIST_POS_SORT);
+    weechat_completion_list_add (completion, "f:recv",
+                                 0, WEECHAT_LIST_POS_SORT);
+    weechat_completion_list_add (completion, "f:redirected",
+                                 0, WEECHAT_LIST_POS_SORT);
+    weechat_completion_list_add (completion, "f:sent",
+                                 0, WEECHAT_LIST_POS_SORT);
+
+    /* IRC command */
+    weechat_completion_list_add (completion, "m:notice",
+                                 0, WEECHAT_LIST_POS_SORT);
+    weechat_completion_list_add (completion, "m:privmsg",
+                                 0, WEECHAT_LIST_POS_SORT);
+
+    /* server */
+    for (ptr_server = irc_servers; ptr_server;
+         ptr_server = ptr_server->next_server)
+    {
+        snprintf (str_filter, sizeof (str_filter), "s:%s", ptr_server->name);
+        weechat_completion_list_add (completion, str_filter,
+                                     0, WEECHAT_LIST_POS_SORT);
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Hooks completions.
  */
@@ -833,6 +977,10 @@ irc_completion_init ()
     weechat_hook_completion ("irc_server_nicks",
                              N_("nicks on all channels of current IRC server"),
                              &irc_completion_server_nicks_cb, NULL, NULL);
+    weechat_hook_completion ("irc_server_prefix_modes_filter",
+                             N_("arguments to filter by prefix mode "
+                                "(for example: \"-o\", \"-h\", \"-v\", \"-*\")"),
+                             &irc_completion_server_prefix_modes_filter_cb, NULL, NULL);
     weechat_hook_completion ("irc_servers",
                              N_("IRC servers (internal names)"),
                              &irc_completion_servers_cb, NULL, NULL);
@@ -859,6 +1007,10 @@ irc_completion_init ()
     weechat_hook_completion ("irc_channels",
                              N_("channels on all IRC servers"),
                              &irc_completion_channels_cb, NULL, NULL);
+    weechat_hook_completion ("irc_channels_autojoin",
+                             N_("channels automatically joined on the current "
+                                "server (option \"autojoin\")"),
+                             &irc_completion_channels_autojoin_cb, NULL, NULL);
     weechat_hook_completion ("irc_privates",
                              N_("privates on all IRC servers"),
                              &irc_completion_privates_cb, NULL, NULL);
@@ -874,4 +1026,7 @@ irc_completion_init ()
     weechat_hook_completion ("irc_notify_nicks",
                              N_("nicks in notify list"),
                              &irc_completion_notify_nicks_cb, NULL, NULL);
+    weechat_hook_completion ("irc_raw_filters",
+                             N_("filters for irc raw buffer"),
+                             &irc_completion_raw_filters_cb, NULL, NULL);
 }
