@@ -23,7 +23,7 @@
 #define IRC_CONFIG_NAME "irc"
 #define IRC_CONFIG_PRIO_NAME (TO_STR(IRC_PLUGIN_PRIORITY) "|" IRC_CONFIG_NAME)
 
-#define IRC_CONFIG_VERSION 2
+#define IRC_CONFIG_VERSION 3
 
 enum t_irc_config_look_server_buffer
 {
@@ -127,8 +127,12 @@ extern struct t_config_option *irc_config_look_item_display_server;
 extern struct t_config_option *irc_config_look_item_nick_modes;
 extern struct t_config_option *irc_config_look_item_nick_prefix;
 extern struct t_config_option *irc_config_look_join_auto_add_chantype;
+extern struct t_config_option *irc_config_look_list_buffer_scroll_horizontal;
+extern struct t_config_option *irc_config_look_list_buffer_sort;
+extern struct t_config_option *irc_config_look_list_buffer_topic_strip_colors;
 extern struct t_config_option *irc_config_look_msgbuffer_fallback;
 extern struct t_config_option *irc_config_look_new_channel_position;
+extern struct t_config_option *irc_config_look_new_list_position;
 extern struct t_config_option *irc_config_look_new_pv_position;
 extern struct t_config_option *irc_config_look_nick_completion_smart;
 extern struct t_config_option *irc_config_look_nick_mode;
@@ -168,6 +172,8 @@ extern struct t_config_option *irc_config_color_item_nick_modes;
 extern struct t_config_option *irc_config_color_item_tls_version_deprecated;
 extern struct t_config_option *irc_config_color_item_tls_version_insecure;
 extern struct t_config_option *irc_config_color_item_tls_version_ok;
+extern struct t_config_option *irc_config_color_list_buffer_line_selected;
+extern struct t_config_option *irc_config_color_list_buffer_line_selected_bg;
 extern struct t_config_option *irc_config_color_message_account;
 extern struct t_config_option *irc_config_color_message_chghost;
 extern struct t_config_option *irc_config_color_message_join;
