@@ -32,6 +32,7 @@
 #include "irc-nick.h"
 #include "irc-color.h"
 #include "irc-config.h"
+#include "irc-list.h"
 #include "irc-msgbuffer.h"
 #include "irc-protocol.h"
 #include "irc-raw.h"
@@ -318,7 +319,8 @@ irc_input_send_user_message (struct t_gui_buffer *buffer, int flags,
         return;
     }
     list_messages = irc_server_sendf (ptr_server,
-                                      flags | IRC_SERVER_SEND_RETURN_LIST,
+                                      flags | IRC_SERVER_SEND_RETURN_LIST
+                                      | IRC_SERVER_SEND_MULTILINE,
                                       tags,
                                       "PRIVMSG %s :%s",
                                       ptr_channel->name, message);
@@ -367,6 +369,12 @@ irc_input_data (struct t_gui_buffer *buffer, const char *input_data, int flags,
         else
             irc_raw_filter_options (input_data);
     }
+    else if (weechat_strcmp (
+                 weechat_buffer_get_string (buffer,
+                                            "localvar_type"), "list") == 0)
+    {
+        irc_list_buffer_input_data (buffer, input_data);
+    }
     else
     {
         /*
@@ -379,7 +387,9 @@ irc_input_data (struct t_gui_buffer *buffer, const char *input_data, int flags,
         {
             if (ptr_server)
             {
-                irc_server_sendf (ptr_server, flags, NULL,
+                irc_server_sendf (ptr_server,
+                                  flags | IRC_SERVER_SEND_MULTILINE,
+                                  NULL,
                                   "%s", weechat_utf8_next_char (input_data));
             }
             return WEECHAT_RC_OK;
