@@ -256,16 +256,15 @@ irc_nick_set_host (struct t_irc_nick *nick, const char *host)
 }
 
 /*
- * Checks if nick is "op" (or better than "op", for example channel admin or
- * channel owner).
+ * Checks if nick is "op" or higher than "op", like channel admin/owner.
  *
  * Returns:
- *   1: nick is "op" (or better)
+ *   1: nick is "op" or higher
  *   0: nick is not op
  */
 
 int
-irc_nick_is_op (struct t_irc_server *server, struct t_irc_nick *nick)
+irc_nick_is_op_or_higher (struct t_irc_server *server, struct t_irc_nick *nick)
 {
     int index;
 
@@ -834,40 +833,66 @@ irc_nick_search (struct t_irc_server *server, struct t_irc_channel *channel,
 }
 
 /*
- * Returns number of nicks (total, op, halfop, voice, normal) on a channel.
+ * Returns number of nicks per mode on a channel, as an array of integers
+ * whose size is the number of modes + 1 (for regular users).
+ *
+ * For example if modes == "ohv", the array returned has a size of 4, with:
+ *   - array[0] = number of nicks with mode "o"
+ *   - array[1] = number of nicks with mode "h"
+ *   - array[2] = number of nicks with mode "v"
+ *   - array[3] = number of nicks with no mode (regular users)
+ *
+ * The parameter *size is set with the array size (number of integers in the
+ * array, NOT the size in bytes).
+ *
+ * Note: result must be freed after use (if not NULL).
  */
 
-void
+int *
 irc_nick_count (struct t_irc_server *server, struct t_irc_channel *channel,
-                int *total, int *count_op, int *count_halfop, int *count_voice,
-                int *count_normal)
+                int *size)
 {
     struct t_irc_nick *ptr_nick;
+    const char *ptr_prefix_modes;
+    int i, *nicks_by_mode, mode_found;
 
-    (*total) = 0;
-    (*count_op) = 0;
-    (*count_halfop) = 0;
-    (*count_voice) = 0;
-    (*count_normal) = 0;
-    for (ptr_nick = channel->nicks; ptr_nick;
-         ptr_nick = ptr_nick->next_nick)
+    if (!server || !channel || !size)
+        return NULL;
+
+    *size = 0;
+
+    ptr_prefix_modes = irc_server_get_prefix_modes (server);
+    if (!ptr_prefix_modes)
+        return NULL;
+
+    *size = strlen (ptr_prefix_modes) + 1;
+    nicks_by_mode = (int *)calloc (*size, sizeof (*nicks_by_mode));
+    if (!nicks_by_mode)
     {
-        (*total)++;
-        if (irc_nick_is_op (server, ptr_nick))
-            (*count_op)++;
-        else
+        *size = 0;
+        return NULL;
+    }
+
+    for (ptr_nick = channel->nicks; ptr_nick; ptr_nick = ptr_nick->next_nick)
+    {
+        mode_found = 0;
+        for (i = 0; ptr_prefix_modes[i]; i++)
         {
-            if (irc_nick_has_prefix_mode (server, ptr_nick, 'h'))
-                (*count_halfop)++;
-            else
+            if (irc_nick_has_prefix_mode (server, ptr_nick, ptr_prefix_modes[i]))
             {
-                if (irc_nick_has_prefix_mode (server, ptr_nick, 'v'))
-                    (*count_voice)++;
-                else
-                    (*count_normal)++;
+                nicks_by_mode[i]++;
+                mode_found = 1;
+                break;
             }
         }
+        if (!mode_found)
+        {
+            /* regular user */
+            nicks_by_mode[*size - 1]++;
+        }
     }
+
+    return nicks_by_mode;
 }
 
 /*
@@ -909,7 +934,7 @@ irc_nick_mode_for_display (struct t_irc_server *server, struct t_irc_nick *nick,
     str_prefix[0] = (nick) ? nick->prefix[0] : '\0';
     str_prefix[1] = '\0';
 
-    nick_mode = weechat_config_integer (irc_config_look_nick_mode);
+    nick_mode = weechat_config_enum (irc_config_look_nick_mode);
     if ((nick_mode == IRC_CONFIG_LOOK_NICK_MODE_BOTH)
         || (prefix && (nick_mode == IRC_CONFIG_LOOK_NICK_MODE_PREFIX))
         || (!prefix && (nick_mode == IRC_CONFIG_LOOK_NICK_MODE_ACTION)))
