@@ -52,8 +52,8 @@ extern int irc_nick_is_nick (struct t_irc_server *server, const char *string);
 extern char *irc_nick_find_color (const char *nickname);
 extern char *irc_nick_find_color_name (const char *nickname);
 extern void irc_nick_set_host (struct t_irc_nick *nick, const char *host);
-extern int irc_nick_is_op (struct t_irc_server *server,
-                           struct t_irc_nick *nick);
+extern int irc_nick_is_op_or_higher (struct t_irc_server *server,
+                                     struct t_irc_nick *nick);
 extern int irc_nick_has_prefix_mode (struct t_irc_server *server,
                                      struct t_irc_nick *nick,
                                      char prefix_mode);
@@ -85,10 +85,8 @@ extern void irc_nick_free_all (struct t_irc_server *server,
 extern struct t_irc_nick *irc_nick_search (struct t_irc_server *server,
                                            struct t_irc_channel *channel,
                                            const char *nickname);
-extern void irc_nick_count (struct t_irc_server *server,
-                            struct t_irc_channel *channel, int *total,
-                            int *count_op, int *count_halfop, int *count_voice,
-                            int *count_normal);
+extern int *irc_nick_count (struct t_irc_server *server,
+                            struct t_irc_channel *channel, int *size);
 extern void irc_nick_set_away (struct t_irc_server *server,
                                struct t_irc_channel *channel,
                                struct t_irc_nick *nick, int is_away);
