@@ -30,6 +30,7 @@
 #include "irc-channel.h"
 #include "irc-config.h"
 #include "irc-input.h"
+#include "irc-list.h"
 #include "irc-modelist.h"
 #include "irc-nick.h"
 #include "irc-notify.h"
@@ -323,6 +324,15 @@ irc_upgrade_set_buffer_callbacks ()
                                                     ptr_server);
                     }
                 }
+                if (type && (strcmp (type, "list") == 0))
+                {
+                    ptr_server = irc_server_search (
+                        weechat_buffer_get_string (ptr_buffer,
+                                                   "localvar_server"));
+                    if (ptr_server)
+                        ptr_server->list->buffer = ptr_buffer;
+                    irc_list_buffer_refresh (ptr_server, 1);
+                }
                 if (strcmp (weechat_infolist_string (infolist, "name"),
                             IRC_RAW_BUFFER_NAME) == 0)
                 {
@@ -416,8 +426,26 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                             irc_upgrade_current_server,
                             NULL);
                     }
+                    /*
+                     * "authentication_method" and "sasl_mechanism_used" are
+                     * new in WeeChat 4.0.0
+                     */
+                    if (weechat_infolist_search_var (infolist, "authentication_method"))
+                    {
+                        irc_upgrade_current_server->authentication_method = weechat_infolist_integer (infolist, "authentication_method");
+                        irc_upgrade_current_server->sasl_mechanism_used = weechat_infolist_integer (infolist, "sasl_mechanism_used");
+                    }
+                    else
+                    {
+                        irc_upgrade_current_server->authentication_method = IRC_SERVER_AUTH_METHOD_NONE;
+                        irc_upgrade_current_server->sasl_mechanism_used = -1;
+                    }
                     irc_upgrade_current_server->is_connected = weechat_infolist_integer (infolist, "is_connected");
-                    irc_upgrade_current_server->ssl_connected = weechat_infolist_integer (infolist, "ssl_connected");
+                    /* "tls_connected" replaces "ssl_connected" in WeeChat 4.0.0 */
+                    if (weechat_infolist_search_var (infolist, "tls_connected"))
+                        irc_upgrade_current_server->tls_connected = weechat_infolist_integer (infolist, "tls_connected");
+                    else
+                        irc_upgrade_current_server->tls_connected = weechat_infolist_integer (infolist, "ssl_connected");
                     irc_upgrade_current_server->disconnected = weechat_infolist_integer (infolist, "disconnected");
                     str = weechat_infolist_string (infolist, "unterminated_message");
                     if (str)
@@ -483,6 +511,24 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                             free (irc_upgrade_current_server->prefix_chars);
                         irc_upgrade_current_server->prefix_chars = strdup (str);
                     }
+                    /* "msg_max_length" is new in WeeChat 4.0.0 */
+                    if (weechat_infolist_search_var (infolist, "msg_max_length"))
+                    {
+                        irc_upgrade_current_server->msg_max_length = weechat_infolist_integer (infolist, "msg_max_length");
+                    }
+                    else
+                    {
+                        /* WeeChat <= 3.8 */
+                        str = irc_server_get_isupport_value (irc_upgrade_current_server,
+                                                             "LINELEN");
+                        if (str)
+                        {
+                            error = NULL;
+                            number = strtol (str, &error, 10);
+                            if (error && !error[0])
+                                irc_upgrade_current_server->msg_max_length = (int)number;
+                        }
+                    }
                     irc_upgrade_current_server->nick_max_length = weechat_infolist_integer (infolist, "nick_max_length");
                     /* "user_max_length" is new in WeeChat 2.6 */
                     if (weechat_infolist_search_var (infolist, "user_max_length"))
@@ -538,6 +584,20 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                                 irc_upgrade_current_server->utf8mapping = utf8mapping;
                         }
                     }
+                    /* "utf8only" is new in WeeChat 4.0.0 */
+                    if (weechat_infolist_search_var (infolist, "utf8only"))
+                    {
+                        irc_upgrade_current_server->utf8only = weechat_infolist_integer (infolist, "utf8only");
+                    }
+                    else
+                    {
+                        /* WeeChat <= 3.8 */
+                        irc_upgrade_current_server->utf8only = (
+                            irc_server_get_isupport_value (
+                                irc_upgrade_current_server,
+                                "UTF8ONLY")) ?
+                            1 : 0;
+                    }
                     str = weechat_infolist_string (infolist, "chantypes");
                     if (str)
                         irc_upgrade_current_server->chantypes = strdup (str);
@@ -589,7 +649,7 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                     irc_upgrade_current_server->reconnect_delay = weechat_infolist_integer (infolist, "reconnect_delay");
                     irc_upgrade_current_server->reconnect_start = weechat_infolist_time (infolist, "reconnect_start");
                     irc_upgrade_current_server->command_time = weechat_infolist_time (infolist, "command_time");
-                    irc_upgrade_current_server->reconnect_join = weechat_infolist_integer (infolist, "reconnect_join");
+                    irc_upgrade_current_server->autojoin_done = weechat_infolist_integer (infolist, "autojoin_done");
                     irc_upgrade_current_server->disable_autojoin = weechat_infolist_integer (infolist, "disable_autojoin");
                     irc_upgrade_current_server->is_away = weechat_infolist_integer (infolist, "is_away");
                     str = weechat_infolist_string (infolist, "away_message");
