@@ -657,7 +657,7 @@ weechat_js_command_cb (const void *pointer, void *data,
             {
                 /* load javascript script */
                 path_script = plugin_script_search_path (weechat_js_plugin,
-                                                         ptr_name);
+                                                         ptr_name, 1);
                 weechat_js_load ((path_script) ? path_script : ptr_name,
                                  NULL);
                 if (path_script)
