@@ -106,6 +106,8 @@ PHP_FUNCTION(weechat_config_string);
 PHP_FUNCTION(weechat_config_string_default);
 PHP_FUNCTION(weechat_config_color);
 PHP_FUNCTION(weechat_config_color_default);
+PHP_FUNCTION(weechat_config_enum);
+PHP_FUNCTION(weechat_config_enum_default);
 PHP_FUNCTION(weechat_config_write_option);
 PHP_FUNCTION(weechat_config_write_line);
 PHP_FUNCTION(weechat_config_write);
@@ -139,6 +141,7 @@ PHP_FUNCTION(weechat_hook_timer);
 PHP_FUNCTION(weechat_hook_fd);
 PHP_FUNCTION(weechat_hook_process);
 PHP_FUNCTION(weechat_hook_process_hashtable);
+PHP_FUNCTION(weechat_hook_url);
 PHP_FUNCTION(weechat_hook_connect);
 PHP_FUNCTION(weechat_hook_line);
 PHP_FUNCTION(weechat_hook_print);
