@@ -1,5 +1,5 @@
 /* This is a generated file, edit the .stub.php file instead.
- * Stub hash: 5c460494eac0e2ed6729ab210df6679f990070d6 */
+ * Stub hash: 614392b6be26030a5d7b12437562aec08ad7052c */
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_weechat_register, 0, 0, 7)
 	ZEND_ARG_INFO(0, p0)
@@ -146,6 +146,10 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_weechat_config_color_default arginfo_weechat_plugin_get_name
 
+#define arginfo_weechat_config_enum arginfo_weechat_plugin_get_name
+
+#define arginfo_weechat_config_enum_default arginfo_weechat_plugin_get_name
+
 #define arginfo_weechat_config_write_option arginfo_weechat_iconv_to_internal
 
 #define arginfo_weechat_config_write_line arginfo_weechat_ngettext
@@ -225,6 +229,8 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_weechat_hook_process_hashtable arginfo_weechat_print_y_date_tags
 
+#define arginfo_weechat_hook_url arginfo_weechat_print_y_date_tags
+
 #define arginfo_weechat_hook_connect arginfo_weechat_list_new
 
 #define arginfo_weechat_hook_line arginfo_weechat_print_y_date_tags
