@@ -469,6 +469,34 @@ plugin_api_info_auto_load_scripts_cb (const void *pointer, void *data,
     return strdup (value);
 }
 
+/*
+ * Returns WeeChat info "buffer".
+ */
+
+char *
+plugin_api_info_buffer_cb (const void *pointer, void *data,
+                           const char *info_name,
+                           const char *arguments)
+{
+    struct t_gui_buffer *ptr_buffer;
+    char value[64];
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+
+    if (!arguments || !arguments[0])
+        return NULL;
+
+    ptr_buffer = gui_buffer_search_by_full_name (arguments);
+    if (!ptr_buffer)
+        return NULL;
+
+    snprintf (value, sizeof (value), "0x%lx", (unsigned long)ptr_buffer);
+    return strdup (value);
+}
+
 /*
  * Returns WeeChat info "charset_terminal".
  */
@@ -787,6 +815,7 @@ plugin_api_info_nick_color_cb (const void *pointer, void *data,
 
     result = gui_nick_find_color (
         (num_items >= 1) ? items[0] : NULL,
+        -1,
         (num_items >= 2) ? items[1] : NULL);
 
     if (items)
@@ -816,6 +845,7 @@ plugin_api_info_nick_color_name_cb (const void *pointer, void *data,
 
     result = gui_nick_find_color_name (
         (num_items >= 1) ? items[0] : NULL,
+        -1,
         (num_items >= 2) ? items[1] : NULL);
 
     if (items)
@@ -824,6 +854,84 @@ plugin_api_info_nick_color_name_cb (const void *pointer, void *data,
     return result;
 }
 
+/*
+ * Returns nick color code for a nickname (case ignored using a range of chars).
+ */
+
+char *
+plugin_api_info_nick_color_ignore_case_cb (const void *pointer, void *data,
+                                           const char *info_name,
+                                           const char *arguments)
+{
+    char **items, *result, *error;
+    int num_items, case_range;
+    long number;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+
+    items = string_split (arguments, ";", NULL, 0, 3, &num_items);
+
+    case_range = -1;
+    if (num_items >= 2)
+    {
+        number = strtol (items[1], &error, 10);
+        if (error && !error[0])
+            case_range = (int)number;
+    }
+
+    result = gui_nick_find_color (
+        (num_items >= 1) ? items[0] : NULL,
+        case_range,
+        (num_items >= 3) ? items[2] : NULL);
+
+    if (items)
+        string_free_split (items);
+
+    return result;
+}
+
+/*
+ * Returns nick color name for a nickname (case ignored using a range of chars).
+ */
+
+char *
+plugin_api_info_nick_color_name_ignore_case_cb (const void *pointer, void *data,
+                                                const char *info_name,
+                                                const char *arguments)
+{
+    char **items, *result, *error;
+    int num_items, case_range;
+    long number;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+
+    items = string_split (arguments, ";", NULL, 0, 3, &num_items);
+
+    case_range = -1;
+    if (num_items >= 2)
+    {
+        number = strtol (items[1], &error, 10);
+        if (error && !error[0])
+            case_range = (int)number;
+    }
+
+    result = gui_nick_find_color_name (
+        (num_items >= 1) ? items[0] : NULL,
+        case_range,
+        (num_items >= 3) ? items[2] : NULL);
+
+    if (items)
+        string_free_split (items);
+
+    return result;
+}
+
 /*
  * Returns uptime according to the start date and arguments.
  */
@@ -1993,6 +2101,10 @@ plugin_api_info_init ()
                   "0 if the auto-load has been disabled by the user "
                   "(option \"-s\" or \"--no-script\")"),
                NULL, &plugin_api_info_auto_load_scripts_cb, NULL, NULL);
+    hook_info (NULL, "buffer",
+               N_("buffer pointer"),
+               N_("buffer full name"),
+               &plugin_api_info_buffer_cb, NULL, NULL);
     hook_info (NULL, "charset_terminal",
                N_("terminal charset"),
                NULL, &plugin_api_info_charset_terminal_cb, NULL, NULL);
@@ -2051,6 +2163,26 @@ plugin_api_info_init ()
                   "options with nick colors and forced nick colors are "
                   "ignored)"),
                &plugin_api_info_nick_color_name_cb, NULL, NULL);
+    hook_info (NULL, "nick_color_ignore_case",
+               N_("get nick color code, ignoring case"),
+               N_("nickname;range;colors (range is a number of chars (see "
+                  "function strcasecmp_range, 0 = convert to lower case without "
+                   "using a range), colors is an optional comma-separated list "
+                  "of colors to use; background is allowed for a color with "
+                  "format text:background; if colors is present, WeeChat "
+                  "options with nick colors and forced nick colors are "
+                  "ignored)"),
+               &plugin_api_info_nick_color_ignore_case_cb, NULL, NULL);
+    hook_info (NULL, "nick_color_name_ignore_case",
+               N_("get nick color name, ignoring case"),
+               N_("nickname;range;colors (range is a number of chars (see "
+                  "function strcasecmp_range, 0 = convert to lower case without "
+                   "using a range), colors is an optional comma-separated list "
+                  "of colors to use; background is allowed for a color with "
+                  "format text:background; if colors is present, WeeChat "
+                  "options with nick colors and forced nick colors are "
+                  "ignored)"),
+               &plugin_api_info_nick_color_name_ignore_case_cb, NULL, NULL);
     hook_info (NULL, "uptime",
                N_("WeeChat uptime (format: \"days:hh:mm:ss\")"),
                N_("\"days\" (number of days) or \"seconds\" (number of "
