@@ -37,6 +37,17 @@ extern struct t_config_file *plugin_script_api_config_new (struct t_weechat_plug
                                                                                   struct t_config_file *config_file),
                                                            const char *function,
                                                            const char *data);
+extern int plugin_script_api_config_set_version (struct t_weechat_plugin *weechat_plugin,
+                                                 struct t_plugin_script *script,
+                                                 struct t_config_file *config_file,
+                                                 int version,
+                                                 struct t_hashtable *(*callback_update)(const void *pointer,
+                                                                                        void *data,
+                                                                                        struct t_config_file *config_file,
+                                                                                        int version_read,
+                                                                                        struct t_hashtable *data_read),
+                                                 const char *function,
+                                                 const char *data);
 extern struct t_config_section *plugin_script_api_config_new_section (struct t_weechat_plugin *weechat_plugin,
                                                                       struct t_plugin_script *script,
                                                                       struct t_config_file *config_file,
@@ -192,6 +203,18 @@ extern struct t_hook *plugin_script_api_hook_process (struct t_weechat_plugin *w
                                                                       const char *err),
                                                       const char *function,
                                                       const char *data);
+extern struct t_hook *plugin_script_api_hook_url (struct t_weechat_plugin *weechat_plugin,
+                                                  struct t_plugin_script *script,
+                                                  const char *url,
+                                                  struct t_hashtable *options,
+                                                  int timeout,
+                                                  int (*callback)(const void *pointer,
+                                                                  void *data,
+                                                                  const char *url,
+                                                                  struct t_hashtable *options,
+                                                                  struct t_hashtable *output),
+                                                  const char *function,
+                                                  const char *data);
 extern struct t_hook *plugin_script_api_hook_connect (struct t_weechat_plugin *weechat_plugin,
                                                       struct t_plugin_script *script,
                                                       const char *proxy,
