@@ -761,6 +761,8 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->config_boolean_default = &config_file_option_boolean_default;
         new_plugin->config_integer = &config_file_option_integer;
         new_plugin->config_integer_default = &config_file_option_integer_default;
+        new_plugin->config_enum = &config_file_option_enum;
+        new_plugin->config_enum_default = &config_file_option_enum_default;
         new_plugin->config_string = &config_file_option_string;
         new_plugin->config_string_default = &config_file_option_string_default;
         new_plugin->config_color = &config_file_option_color;
@@ -796,6 +798,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->hook_fd = &hook_fd;
         new_plugin->hook_process = &hook_process;
         new_plugin->hook_process_hashtable = &hook_process_hashtable;
+        new_plugin->hook_url = &hook_url;
         new_plugin->hook_connect = &hook_connect;
         new_plugin->hook_line = &hook_line;
         new_plugin->hook_print = &hook_print;
