@@ -1201,7 +1201,7 @@ weechat_python_command_cb (const void *pointer, void *data,
             {
                 /* load python script */
                 path_script = plugin_script_search_path (weechat_python_plugin,
-                                                         ptr_name);
+                                                         ptr_name, 1);
                 weechat_python_load ((path_script) ? path_script : ptr_name,
                                      NULL);
                 if (path_script)
