@@ -150,6 +150,9 @@ relay_client_status_search (const char *name)
 {
     int i;
 
+    if (!name)
+        return -1;
+
     for (i = 0; i < RELAY_NUM_STATUS; i++)
     {
         if (strcmp (relay_client_status_name[i], name) == 0)
@@ -215,7 +218,7 @@ relay_client_set_desc (struct t_relay_client *client)
     snprintf (desc, sizeof (desc),
               "%d/%s%s%s%s/%s%s%s%s",
               client->id,
-              (client->ssl) ? "ssl." : "",
+              (client->tls) ? "tls." : "",
               relay_protocol_string[client->protocol],
               (client->protocol_args) ? "." : "",
               (client->protocol_args) ? client->protocol_args : "",
@@ -228,7 +231,7 @@ relay_client_set_desc (struct t_relay_client *client)
 }
 
 /*
- * Timer callback for handshake with client (for SSL connection only).
+ * Timer callback for handshake with client (for TLS connection only).
  */
 
 int
@@ -588,6 +591,9 @@ relay_client_recv_cb (const void *pointer, void *data, int fd)
 
     client = (struct t_relay_client *)pointer;
 
+    if (client->sock < 0)
+        return WEECHAT_RC_OK;
+
     /*
      * data can be received only during authentication
      * or if connected (authentication was OK)
@@ -598,7 +604,7 @@ relay_client_recv_cb (const void *pointer, void *data, int fd)
         return WEECHAT_RC_OK;
     }
 
-    if (client->ssl)
+    if (client->tls)
         num_read = gnutls_record_recv (client->gnutls_sess, buffer,
                                        sizeof (buffer) - 1);
     else
@@ -687,7 +693,7 @@ relay_client_recv_cb (const void *pointer, void *data, int fd)
     }
     else
     {
-        if (client->ssl)
+        if (client->tls)
         {
             if ((num_read == 0)
                 || ((num_read != GNUTLS_E_AGAIN) && (num_read != GNUTLS_E_INTERRUPTED)))
@@ -795,17 +801,21 @@ relay_client_send_outqueue (struct t_relay_client *client)
 
     while (client->outqueue)
     {
-        if (client->ssl)
+        if (client->tls)
         {
-            num_sent = gnutls_record_send (client->gnutls_sess,
-                                           client->outqueue->data,
-                                           client->outqueue->data_size);
+            num_sent = (client->sock >= 0) ?
+                gnutls_record_send (client->gnutls_sess,
+                                    client->outqueue->data,
+                                    client->outqueue->data_size) :
+                client->outqueue->data_size;
         }
         else
         {
-            num_sent = send (client->sock,
-                             client->outqueue->data,
-                             client->outqueue->data_size, 0);
+            num_sent = (client->sock >= 0) ?
+                send (client->sock,
+                      client->outqueue->data,
+                      client->outqueue->data_size, 0) :
+                client->outqueue->data_size;
         }
         if (num_sent >= 0)
         {
@@ -864,7 +874,7 @@ relay_client_send_outqueue (struct t_relay_client *client)
         }
         else
         {
-            if (client->ssl)
+            if (client->tls)
             {
                 if ((num_sent == GNUTLS_E_AGAIN)
                     || (num_sent == GNUTLS_E_INTERRUPTED))
@@ -1134,10 +1144,17 @@ relay_client_send (struct t_relay_client *client,
     }
     else
     {
-        if (client->ssl)
-            num_sent = gnutls_record_send (client->gnutls_sess, ptr_data, data_size);
+        if (client->tls)
+        {
+            num_sent = (client->sock >= 0) ?
+                gnutls_record_send (client->gnutls_sess, ptr_data, data_size) :
+                data_size;
+        }
         else
-            num_sent = send (client->sock, ptr_data, data_size, 0);
+        {
+            num_sent = (client->sock >= 0) ?
+                send (client->sock, ptr_data, data_size, 0) : data_size;
+        }
 
         if (num_sent >= 0)
         {
@@ -1165,7 +1182,7 @@ relay_client_send (struct t_relay_client *client,
         }
         else
         {
-            if (client->ssl)
+            if (client->tls)
             {
                 if ((num_sent == GNUTLS_E_AGAIN)
                     || (num_sent == GNUTLS_E_INTERRUPTED))
@@ -1303,7 +1320,8 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
         new_client->desc = NULL;
         new_client->sock = sock;
         new_client->server_port = server->port;
-        new_client->ssl = server->ssl;
+        new_client->tls = server->tls;
+        new_client->gnutls_sess = NULL;
         new_client->hook_timer_handshake = NULL;
         new_client->gnutls_handshake_ok = 0;
         new_client->websocket = RELAY_CLIENT_WEBSOCKET_NOT_USED;
@@ -1351,20 +1369,20 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
 
         relay_client_set_desc (new_client);
 
-        if (new_client->ssl)
+        if (new_client->tls)
         {
-            if (!relay_network_init_ssl_cert_key_ok)
+            if (!relay_network_init_tls_cert_key_ok)
             {
                 weechat_printf_date_tags (
                     NULL, 0, "relay_client",
-                    _("%s%s: warning: no SSL certificate/key found (option "
-                      "relay.network.ssl_cert_key)"),
+                    _("%s%s: warning: no TLS certificate/key found (option "
+                      "relay.network.tls_cert_key)"),
                     weechat_prefix ("error"),
                     RELAY_PLUGIN_NAME);
             }
             new_client->status = RELAY_STATUS_CONNECTING;
             /*
-             * set Diffie-Hellman parameters on first SSL connection from a
+             * set Diffie-Hellman parameters on first TLS connection from a
              * client (done only one time)
              */
             if (!relay_gnutls_dh_params)
@@ -1407,7 +1425,7 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
         {
             case RELAY_PROTOCOL_WEECHAT:
                 relay_weechat_alloc (new_client);
-                if (!new_client->ssl)
+                if (!new_client->tls)
                 {
                     new_client->status =
                         relay_weechat_get_initial_status (new_client);
@@ -1415,7 +1433,7 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
                 break;
             case RELAY_PROTOCOL_IRC:
                 relay_irc_alloc (new_client);
-                if (!new_client->ssl)
+                if (!new_client->tls)
                 {
                     new_client->status =
                         relay_irc_get_initial_status (new_client);
@@ -1461,10 +1479,13 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
                 _(relay_client_status_string[new_client->status]));
         }
 
-        new_client->hook_fd = weechat_hook_fd (new_client->sock,
-                                               1, 0, 0,
-                                               &relay_client_recv_cb,
-                                               new_client, NULL);
+        if (new_client->sock >= 0)
+        {
+            new_client->hook_fd = weechat_hook_fd (new_client->sock,
+                                                   1, 0, 0,
+                                                   &relay_client_recv_cb,
+                                                   new_client, NULL);
+        }
 
         relay_client_count++;
 
@@ -1507,7 +1528,11 @@ relay_client_new_with_infolist (struct t_infolist *infolist)
         new_client->desc = NULL;
         new_client->sock = weechat_infolist_integer (infolist, "sock");
         new_client->server_port = weechat_infolist_integer (infolist, "server_port");
-        new_client->ssl = weechat_infolist_integer (infolist, "ssl");
+        /* "tls" replaces "ssl" in WeeChat 4.0.0 */
+        if (weechat_infolist_search_var (infolist, "tls"))
+            new_client->tls = weechat_infolist_integer (infolist, "tls");
+        else
+            new_client->tls = weechat_infolist_integer (infolist, "ssl");
         new_client->gnutls_sess = NULL;
         new_client->hook_timer_handshake = NULL;
         new_client->gnutls_handshake_ok = 0;
@@ -1693,11 +1718,11 @@ relay_client_set_status (struct t_relay_client *client,
 
         if (client->sock >= 0)
         {
-            if (client->ssl && client->gnutls_handshake_ok)
+            if (client->tls && client->gnutls_handshake_ok)
                 gnutls_bye (client->gnutls_sess, GNUTLS_SHUT_WR);
             close (client->sock);
             client->sock = -1;
-            if (client->ssl)
+            if (client->tls)
                 gnutls_deinit (client->gnutls_sess);
         }
     }
@@ -1888,7 +1913,7 @@ relay_client_add_to_infolist (struct t_infolist *infolist,
     }
     if (!weechat_infolist_new_var_integer (ptr_item, "server_port", client->server_port))
         return 0;
-    if (!weechat_infolist_new_var_integer (ptr_item, "ssl", client->ssl))
+    if (!weechat_infolist_new_var_integer (ptr_item, "tls", client->tls))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "websocket", client->websocket))
         return 0;
@@ -1968,7 +1993,7 @@ relay_client_print_log ()
         weechat_log_printf ("  desc. . . . . . . . . . . : '%s'", ptr_client->desc);
         weechat_log_printf ("  sock. . . . . . . . . . . : %d",   ptr_client->sock);
         weechat_log_printf ("  server_port . . . . . . . : %d",   ptr_client->server_port);
-        weechat_log_printf ("  ssl . . . . . . . . . . . : %d",   ptr_client->ssl);
+        weechat_log_printf ("  tls . . . . . . . . . . . : %d",   ptr_client->tls);
         weechat_log_printf ("  gnutls_sess . . . . . . . : 0x%lx", ptr_client->gnutls_sess);
         weechat_log_printf ("  hook_timer_handshake. . . : 0x%lx", ptr_client->hook_timer_handshake);
         weechat_log_printf ("  gnutls_handshake_ok . . . : 0x%lx", ptr_client->gnutls_handshake_ok);
