@@ -20,6 +20,7 @@
  */
 
 #include <stdlib.h>
+#include <unistd.h>
 
 #include <gnutls/gnutls.h>
 
@@ -30,7 +31,7 @@
 
 
 int relay_network_init_ok = 0;
-int relay_network_init_ssl_cert_key_ok = 0;
+int relay_network_init_tls_cert_key_ok = 0;
 
 gnutls_certificate_credentials_t relay_gnutls_x509_cred;
 gnutls_priority_t *relay_gnutls_priority_cache = NULL;
@@ -38,15 +39,16 @@ gnutls_dh_params_t *relay_gnutls_dh_params = NULL;
 
 
 /*
- * Sets SSL certificate/key file.
+ * Sets TLS certificate/key file.
  *
  * If verbose == 1, a message is displayed if successful, otherwise a warning
  * (if no cert/key found in file).
  */
 
 void
-relay_network_set_ssl_cert_key (int verbose)
+relay_network_set_tls_cert_key (int verbose)
 {
+    const char *ptr_path;
     char *certkey_path;
     int ret;
     struct t_hashtable *options;
@@ -54,7 +56,21 @@ relay_network_set_ssl_cert_key (int verbose)
     gnutls_certificate_free_credentials (relay_gnutls_x509_cred);
     gnutls_certificate_allocate_credentials (&relay_gnutls_x509_cred);
 
-    relay_network_init_ssl_cert_key_ok = 0;
+    relay_network_init_tls_cert_key_ok = 0;
+
+    ptr_path = weechat_config_string (relay_config_network_tls_cert_key);
+
+    if (!ptr_path || !ptr_path[0])
+    {
+        if (verbose)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: no TLS certificate/key found (option "
+                              "relay.network.tls_cert_key is empty)"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+        }
+        return;
+    }
 
     options = weechat_hashtable_new (
         32,
@@ -63,26 +79,42 @@ relay_network_set_ssl_cert_key (int verbose)
         NULL, NULL);
     if (options)
         weechat_hashtable_set (options, "directory", "config");
-    certkey_path = weechat_string_eval_path_home (
-        weechat_config_string (relay_config_network_ssl_cert_key),
-        NULL, NULL, options);
+    certkey_path = weechat_string_eval_path_home (ptr_path,
+                                                  NULL, NULL, options);
     if (options)
         weechat_hashtable_free (options);
-    if (certkey_path)
+
+    if (certkey_path && certkey_path[0])
     {
-        ret = gnutls_certificate_set_x509_key_file (relay_gnutls_x509_cred,
-                                                    certkey_path,
-                                                    certkey_path,
-                                                    GNUTLS_X509_FMT_PEM);
-        if (ret >= 0)
+        if (access (certkey_path, R_OK) == 0)
         {
-            relay_network_init_ssl_cert_key_ok = 1;
-            if (verbose)
+            ret = gnutls_certificate_set_x509_key_file (relay_gnutls_x509_cred,
+                                                        certkey_path,
+                                                        certkey_path,
+                                                        GNUTLS_X509_FMT_PEM);
+            if (ret >= 0)
             {
-                weechat_printf (NULL,
-                                _("%s: SSL certificate and key have been "
-                                  "set"),
-                                RELAY_PLUGIN_NAME);
+                relay_network_init_tls_cert_key_ok = 1;
+                if (verbose)
+                {
+                    weechat_printf (NULL,
+                                    _("%s: TLS certificate and key have been "
+                                      "set"),
+                                    RELAY_PLUGIN_NAME);
+                }
+            }
+            else
+            {
+                if (verbose)
+                {
+                    weechat_printf (NULL,
+                                    _("%s%s: gnutls error: %s: %s "
+                                      "(option relay.network.tls_cert_key)"),
+                                    weechat_prefix ("error"),
+                                    RELAY_PLUGIN_NAME,
+                                    gnutls_strerror_name (ret),
+                                    gnutls_strerror (ret));
+                }
             }
         }
         else
@@ -90,13 +122,17 @@ relay_network_set_ssl_cert_key (int verbose)
             if (verbose)
             {
                 weechat_printf (NULL,
-                                _("%s%s: warning: no SSL certificate/key "
-                                  "found (option relay.network.ssl_cert_key)"),
-                                weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+                                _("%s%s: error: file with TLS certificate/key "
+                                  "is not readable: \"%s\" "
+                                  "(option relay.network.tls_cert_key)"),
+                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                                certkey_path);
             }
         }
-        free (certkey_path);
     }
+
+    if (certkey_path)
+        free (certkey_path);
 }
 
 /*
@@ -108,11 +144,11 @@ relay_network_set_priority ()
 {
     if (gnutls_priority_init (relay_gnutls_priority_cache,
                               weechat_config_string (
-                                  relay_config_network_ssl_priorities),
+                                  relay_config_network_tls_priorities),
                               NULL) != GNUTLS_E_SUCCESS)
     {
         weechat_printf (NULL,
-                        _("%s%s: unable to initialize priority for SSL"),
+                        _("%s%s: unable to initialize priority for TLS"),
                         weechat_prefix ("error"), RELAY_PLUGIN_NAME);
         free (relay_gnutls_priority_cache);
         relay_gnutls_priority_cache = NULL;
@@ -128,7 +164,7 @@ relay_network_init ()
 {
     /* credentials */
     gnutls_certificate_allocate_credentials (&relay_gnutls_x509_cred);
-    relay_network_set_ssl_cert_key (0);
+    relay_network_set_tls_cert_key (0);
 
     /* priority */
     relay_gnutls_priority_cache = malloc (sizeof (*relay_gnutls_priority_cache));
