@@ -23,13 +23,13 @@
 #include <gnutls/gnutls.h>
 
 extern int relay_network_init_ok;
-extern int relay_network_init_ssl_cert_key_ok;
+extern int relay_network_init_tls_cert_key_ok;
 
 extern gnutls_certificate_credentials_t relay_gnutls_x509_cred;
 extern gnutls_priority_t *relay_gnutls_priority_cache;
 extern gnutls_dh_params_t *relay_gnutls_dh_params;
 
-extern void relay_network_set_ssl_cert_key (int verbose);
+extern void relay_network_set_tls_cert_key (int verbose);
 extern void relay_network_set_priority ();
 extern void relay_network_init ();
 extern void relay_network_end ();
