@@ -1085,38 +1085,51 @@ script_buffer_set_callbacks ()
 
 /*
  * Sets keys on script buffer.
+ *
+ * If hashtable is not NULL, it is used to set keys, otherwise keys are directly
+ * set in the script buffer.
  */
 
 void
-script_buffer_set_keys ()
+script_buffer_set_keys (struct t_hashtable *hashtable)
 {
-    char *keys[][2] = { { "meta-A",  "toggleautoload" },
-                        { "meta-l",  "load"           },
-                        { "meta-u",  "unload"         },
-                        { "meta-L",  "reload"         },
-                        { "meta-i",  "install"        },
-                        { "meta-r",  "remove"         },
-                        { "meta-h",  "hold"           },
-                        { "meta-v",  "show"           },
-                        { "meta-d",  "showdiff"       },
-                        { NULL,     NULL              } };
+    char *keys[][2] = {
+        { "up",     "-up"            },
+        { "down",   "-down"          },
+        { "meta-A", "toggleautoload" },
+        { "meta-l", "load"           },
+        { "meta-u", "unload"         },
+        { "meta-L", "reload"         },
+        { "meta-i", "install"        },
+        { "meta-r", "remove"         },
+        { "meta-h", "hold"           },
+        { "meta-v", "show"           },
+        { "meta-d", "showdiff"       },
+        { NULL, NULL },
+    };
     char str_key[64], str_command[64];
     int i;
 
-    weechat_buffer_set (script_buffer, "key_bind_meta2-A", "/script up");
-    weechat_buffer_set (script_buffer, "key_bind_meta2-B", "/script down");
     for (i = 0; keys[i][0]; i++)
     {
-        if (weechat_config_boolean (script_config_look_use_keys))
+        if (weechat_config_boolean (script_config_look_use_keys)
+            || (strcmp (keys[i][1], "-up") == 0)
+            || (strcmp (keys[i][1], "-down") == 0))
         {
             snprintf (str_key, sizeof (str_key), "key_bind_%s", keys[i][0]);
             snprintf (str_command, sizeof (str_command), "/script %s", keys[i][1]);
-            weechat_buffer_set (script_buffer, str_key, str_command);
+            if (hashtable)
+                weechat_hashtable_set (hashtable, str_key, str_command);
+            else
+                weechat_buffer_set (script_buffer, str_key, str_command);
         }
         else
         {
             snprintf (str_key, sizeof (str_key), "key_unbind_%s", keys[i][0]);
-            weechat_buffer_set (script_buffer, str_key, "");
+            if (hashtable)
+                weechat_hashtable_set (hashtable, str_key, "");
+            else
+                weechat_buffer_set (script_buffer, str_key, "");
         }
     }
 }
@@ -1142,24 +1155,38 @@ script_buffer_set_localvar_filter ()
 void
 script_buffer_open ()
 {
-    if (!script_buffer)
+    struct t_hashtable *buffer_props;
+
+    if (script_buffer)
+        return;
+
+    buffer_props = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (buffer_props)
     {
-        script_buffer = weechat_buffer_new (
-            SCRIPT_BUFFER_NAME,
-            &script_buffer_input_cb, NULL, NULL,
-            &script_buffer_close_cb, NULL, NULL);
-
-        /* failed to create buffer ? then exit */
-        if (!script_buffer)
-            return;
-
-        weechat_buffer_set (script_buffer, "type", "free");
-        weechat_buffer_set (script_buffer, "title", _("Scripts"));
-        script_buffer_set_keys ();
-        weechat_buffer_set (script_buffer, "localvar_set_type", "script");
-        script_buffer_set_localvar_filter ();
-
-        script_buffer_selected_line = 0;
-        script_buffer_detail_script = NULL;
+        weechat_hashtable_set (buffer_props, "type", "free");
+        weechat_hashtable_set (buffer_props, "title", _("Scripts"));
+        weechat_hashtable_set (buffer_props, "localvar_set_type", "script");
+        script_buffer_set_keys (buffer_props);
     }
+
+    script_buffer = weechat_buffer_new_props (
+        SCRIPT_BUFFER_NAME,
+        buffer_props,
+        &script_buffer_input_cb, NULL, NULL,
+        &script_buffer_close_cb, NULL, NULL);
+
+    if (buffer_props)
+        weechat_hashtable_free (buffer_props);
+
+    if (!script_buffer)
+        return;
+
+    script_buffer_set_localvar_filter ();
+
+    script_buffer_selected_line = 0;
+    script_buffer_detail_script = NULL;
 }
