@@ -48,7 +48,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Spell checker for input"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
-WEECHAT_PLUGIN_PRIORITY(12000);
+WEECHAT_PLUGIN_PRIORITY(SPELL_PLUGIN_PRIORITY);
 
 struct t_weechat_plugin *weechat_spell_plugin = NULL;
 
@@ -351,8 +351,7 @@ spell_command_authorized (const char *command)
     for (i = 0; i < spell_count_commands_to_check; i++)
     {
         if ((spell_length_commands_to_check[i] == length_command)
-            && (weechat_strcasecmp (command,
-                                    spell_commands_to_check[i]) == 0))
+            && (strcmp (command, spell_commands_to_check[i]) == 0))
         {
             /* command is authorized */
             return 1;
