@@ -331,6 +331,18 @@ xfer_network_send_file_fork (struct t_xfer *xfer)
 
     xfer->file = open (xfer->local_filename, O_RDONLY | O_NONBLOCK, 0644);
 
+    if (xfer->file < 0)
+    {
+        weechat_printf (NULL,
+                        _("%s%s: unable to read file \"%s\": %s"),
+                        weechat_prefix ("error"),
+                        XFER_PLUGIN_NAME,
+                        xfer->local_filename,
+                        strerror (errno));
+        xfer_close (xfer, XFER_STATUS_FAILED);
+        xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+    }
+
     switch (pid = fork ())
     {
         case -1:  /* fork failed */
@@ -408,6 +420,19 @@ xfer_network_recv_file_fork (struct t_xfer *xfer)
                            0644);
     }
 
+    if (xfer->file < 0)
+    {
+        weechat_printf (NULL,
+                        _("%s%s: unable to write file \"%s\": %s"),
+                        weechat_prefix ("error"),
+                        XFER_PLUGIN_NAME,
+                        xfer->temp_local_filename,
+                        strerror (errno));
+        xfer_close (xfer, XFER_STATUS_FAILED);
+        xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+        return;
+    }
+
     switch (pid = fork ())
     {
         case -1:  /* fork failed */
@@ -458,7 +483,8 @@ xfer_network_child_kill (struct t_xfer *xfer)
     if (xfer->child_pid > 0)
     {
         kill (xfer->child_pid, SIGKILL);
-        waitpid (xfer->child_pid, NULL, 0);
+        weechat_command (weechat_buffer_search_main (),
+                         "/mute /wait 100ms /sys waitpid");
         xfer->child_pid = 0;
     }
 
@@ -498,7 +524,7 @@ xfer_network_fd_cb (const void *pointer, void *data, int fd)
 
     if (xfer->status == XFER_STATUS_CONNECTING)
     {
-        if (xfer->type == XFER_TYPE_FILE_SEND)
+        if (XFER_IS_FILE_PASSIVE(xfer->type))
         {
             xfer->last_activity = time (NULL);
             sock = accept (xfer->sock,
@@ -546,7 +572,22 @@ xfer_network_fd_cb (const void *pointer, void *data, int fd)
             xfer->status = XFER_STATUS_ACTIVE;
             xfer->start_transfer = time (NULL);
             xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
-            xfer_network_send_file_fork (xfer);
+            switch (xfer->type)
+            {
+                case XFER_TYPE_FILE_SEND_PASSIVE:
+                    xfer_network_send_file_fork (xfer);
+                    break;
+                case XFER_TYPE_FILE_RECV_PASSIVE:
+                    xfer_network_recv_file_fork (xfer);
+                    break;
+                default:
+                    weechat_printf (NULL,
+                                    _("%s%s: encountered unexpected xfer type (%d)"),
+                                    weechat_prefix ("error"), XFER_PLUGIN_NAME, xfer->type);
+                    xfer_close (xfer, XFER_STATUS_FAILED);
+                    xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+                    return WEECHAT_RC_OK;
+            }
         }
     }
 
@@ -787,7 +828,7 @@ xfer_network_connect (struct t_xfer *xfer)
     else
         xfer->status = XFER_STATUS_CONNECTING;
 
-    if (XFER_IS_SEND(xfer->type))
+    if (XFER_IS_SEND(xfer->type) || (xfer->type == XFER_TYPE_FILE_RECV_PASSIVE))
     {
         /* create socket */
         if (xfer->sock < 0)
@@ -822,6 +863,10 @@ xfer_network_connect (struct t_xfer *xfer)
                                                    &xfer_network_timer_cb,
                                                    xfer, NULL);
         }
+
+        /* send signal if type is file or chat "send" */
+        if ((xfer->type == XFER_TYPE_FILE_RECV_PASSIVE) && !XFER_HAS_ENDED(xfer->status))
+            xfer_send_signal (xfer, "xfer_send_ready");
     }
 
     /* for chat receiving, connect to listening host */
@@ -853,11 +898,10 @@ xfer_network_connect_init (struct t_xfer *xfer)
     }
     else
     {
-        /* for a file: launch child process */
-        if (XFER_IS_FILE(xfer->type))
-            xfer_network_recv_file_fork (xfer);
-
         xfer->status = XFER_STATUS_CONNECTING;
+        /* for a file: launch child process */
+        if (XFER_IS_FILE(xfer->type) && XFER_IS_ACTIVE(xfer->type))
+            xfer_network_recv_file_fork (xfer);
     }
     xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
 }
