@@ -254,7 +254,7 @@ def test_config():
     check(weechat.config_option_reset(ptr_opt_int, 1) == 2)  # SET_OK_CHANGED
     check(weechat.config_option_reset(ptr_opt_int, 1) == 1)  # SET_OK_SAME_VALUE
     check(weechat.config_integer(ptr_opt_int) == 2)
-    # integer option (with string values)
+    # integer option (with string values: enum with WeeChat >= 4.1.0)
     ptr_opt_int_str = weechat.config_new_option(
         ptr_config, ptr_section, 'option_int_str', 'integer', 'int option str',
         'val1|val2|val3', 0, 0, 'val2', 'val2', 0,
@@ -318,6 +318,31 @@ def test_config():
     check(weechat.config_option_reset(ptr_opt_col, 1) == 2)  # SET_OK_CHANGED
     check(weechat.config_option_reset(ptr_opt_col, 1) == 1)  # SET_OK_SAME_VALUE
     check(weechat.config_color(ptr_opt_col) == 'lightgreen')
+    # enum option
+    ptr_opt_enum = weechat.config_new_option(
+        ptr_config, ptr_section, 'option_enum', 'enum', 'enum option',
+        'val1|val2|val3', 0, 0, 'val2', 'val2', 0,
+        'option_check_value_cb', '',
+        'option_change_cb', '',
+        'option_delete_cb', '',
+    )
+    check(ptr_opt_enum != '')
+    check(weechat.config_enum(ptr_opt_enum) == 1)
+    check(weechat.config_integer(ptr_opt_enum) == 1)
+    check(weechat.config_string(ptr_opt_enum) == 'val2')
+    check(weechat.config_option_set(ptr_opt_enum, 'val1', 1) == 2)  # SET_OK_CHANGED
+    check(weechat.config_option_set(ptr_opt_enum, 'val1', 1) == 1)  # SET_OK_SAME_VALUE
+    check(weechat.config_enum(ptr_opt_enum) == 0)
+    check(weechat.config_integer(ptr_opt_enum) == 0)
+    check(weechat.config_string(ptr_opt_enum) == 'val1')
+    check(weechat.config_enum_default(ptr_opt_enum) == 1)
+    check(weechat.config_integer_default(ptr_opt_enum) == 1)
+    check(weechat.config_string_default(ptr_opt_enum) == 'val2')
+    check(weechat.config_option_reset(ptr_opt_enum, 1) == 2)  # SET_OK_CHANGED
+    check(weechat.config_option_reset(ptr_opt_enum, 1) == 1)  # SET_OK_SAME_VALUE
+    check(weechat.config_enum(ptr_opt_enum) == 1)
+    check(weechat.config_integer(ptr_opt_enum) == 1)
+    check(weechat.config_string(ptr_opt_enum) == 'val2')
     # search option
     ptr_opt_bool2 = weechat.config_search_option(ptr_config, ptr_section,
                                                  'option_bool')
@@ -398,7 +423,7 @@ def test_display():
     weechat.prnt_date_tags('', 946681200, 'tag1,tag2',
                            '## test print_date_tags core buffer')
     weechat.prnt_date_tags('', 2146383600, 'tag1,tag2',
-                           '## test print_date_tags core buffer, 2038-01-06 09:40:00')
+                           '## test print_date_tags core buffer, January, 6th 2038')
     hdata_buffer = weechat.hdata_get('buffer')
     hdata_lines = weechat.hdata_get('lines')
     hdata_line = weechat.hdata_get('line')
@@ -424,7 +449,7 @@ def test_display():
     weechat.prnt_y_date_tags(buffer, 0, 946681200, 'tag1,tag2',
                              '## test print_y_date_tags free buffer')
     weechat.prnt_y_date_tags(buffer, 1, 2146383600, 'tag1,tag2',
-                             '## test print_y_date_tags free buffer, 2038-01-06 09:40:00')
+                             '## test print_y_date_tags free buffer, January, 6th 2038')
     weechat.buffer_close(buffer)
 
 
@@ -599,7 +624,7 @@ def test_hdata():
     # hdata_char
     check(weechat.hdata_char(hdata_line_data, line1_data, 'displayed') == 1)
     # hdata_integer
-    check(weechat.hdata_char(hdata_buffer, buffer2, 'number') == 2)
+    check(weechat.hdata_integer(hdata_buffer, buffer2, 'number') == 2)
     # hdata_long
     weechat.buffer_set(buffer, 'hotlist', weechat.WEECHAT_HOTLIST_MESSAGE)
     gui_hotlist = weechat.hdata_get_list(hdata_hotlist, 'gui_hotlist')
