@@ -222,7 +222,7 @@ TEST(CoreInfolist, New)
     /* check content of variable */
     STRCMP_EQUAL("test_time", var_time->name);
     LONGS_EQUAL(INFOLIST_TIME, var_time->type);
-    LONGS_EQUAL(1234567890, *((int *)var_time->value));
+    LONGS_EQUAL(1234567890, *((time_t *)var_time->value));
     LONGS_EQUAL(0, var_time->size);
     POINTERS_EQUAL(var_buf, var_time->prev_var);
     POINTERS_EQUAL(NULL, var_time->next_var);
@@ -314,6 +314,10 @@ TEST(CoreInfolist, Move)
 
     POINTERS_EQUAL(NULL, infolist->ptr_item);
 
+    infolist_next (NULL);
+    infolist_prev (NULL);
+    infolist_reset_item_cursor (NULL);
+
     /* move to first item in infolist */
     POINTERS_EQUAL(infolist->items, infolist_next (infolist));
     POINTERS_EQUAL(infolist->items, infolist->ptr_item);
